@@ -22,14 +22,17 @@ from gt.extended.genome_stream import GenomeStream
 
 
 class DuplicateFeatureStream(GenomeStream):
+
     def __init__(self, genome_stream, dest_type, source_type):
-        self.gs = gtlib.gt_dup_feature_stream_new(genome_stream._as_parameter_, dest_type,
-                source_type)
+        self.gs = gtlib.gt_dup_feature_stream_new(genome_stream._as_parameter_,
+                                                  str(dest_type).encode(
+                                                      'UTF-8'),
+                                                  str(source_type).encode('UTF-8'))
         self._as_parameter_ = self.gs
 
     def from_param(cls, obj):
         if not isinstance(obj, DuplicateFeatureStream):
-            raise TypeError, "argument must be a DuplicateFeatureStream"
+            raise TypeError("argument must be a DuplicateFeatureStream")
         return obj._as_parameter_
 
     from_param = classmethod(from_param)
@@ -38,6 +41,6 @@ class DuplicateFeatureStream(GenomeStream):
         from ctypes import c_void_p, c_char_p
         gtlib.gt_dup_feature_stream_new.restype = c_void_p
         gtlib.gt_dup_feature_stream_new.argtypes = [c_void_p, c_char_p,
-                c_char_p]
+                                                    c_char_p]
 
     register = classmethod(register)
