@@ -67,7 +67,6 @@ int gt_canvas_cairo_visit_track_pre(GtCanvas *canvas, GtTrack *track,
   int had_err = 0;
   GtUword exceeded;
   bool show_track_captions = true;
-
   GtColor color;
 
   gt_assert(canvas && track);
@@ -91,6 +90,7 @@ int gt_canvas_cairo_visit_track_pre(GtCanvas *canvas, GtTrack *track,
   {
     double theight      = gt_graphics_get_text_height(canvas->pvt->g),
            captionspace = CAPTION_BAR_SPACE_DEFAULT;
+    GtStr *fontfam = NULL;
     if (gt_style_get_num(canvas->pvt->sty,
                           "format", "track_caption_font_size",
                           &theight, NULL, err) == GT_STYLE_QUERY_ERROR) {
@@ -101,8 +101,15 @@ int gt_canvas_cairo_visit_track_pre(GtCanvas *canvas, GtTrack *track,
                          &captionspace, NULL, err ) == GT_STYLE_QUERY_ERROR) {
       return -1;
     }
+    fontfam = gt_str_new_cstr("Sans");
+    if (gt_style_get_str(canvas->pvt->sty,
+                         "format", "track_caption_font_family",
+                         fontfam, NULL, err ) == GT_STYLE_QUERY_ERROR) {
+      gt_str_delete(fontfam);
+      return -1;
+    }
     gt_graphics_set_font(canvas->pvt->g,
-                         "Sans",
+                         gt_str_get(fontfam),
                          SLANT_NORMAL,
                          WEIGHT_NORMAL,
                          theight);
@@ -142,6 +149,7 @@ int gt_canvas_cairo_visit_track_pre(GtCanvas *canvas, GtTrack *track,
                                     buf);
     }
     canvas->pvt->y += captionspace;
+    gt_str_delete(fontfam);
   }
   return had_err;
 }
@@ -289,6 +297,7 @@ int gt_canvas_cairo_visit_block(GtCanvas *canvas, GtBlock *block,
   /* draw block caption */
   if (gt_block_caption_is_visible(block))
   {
+    GtStr *fontfam = NULL;
     caption = gt_str_get(gt_block_get_caption(block));
     if (caption)
     {
@@ -304,11 +313,19 @@ int gt_canvas_cairo_visit_block(GtCanvas *canvas, GtBlock *block,
                           &theight, NULL, err) == GT_STYLE_QUERY_ERROR) {
         return -1;
       }
+      fontfam = gt_str_new_cstr("Sans");
+      if (gt_style_get_str(canvas->pvt->sty,
+                           "format", "block_caption_font_family",
+                           fontfam, NULL, err ) == GT_STYLE_QUERY_ERROR) {
+        gt_str_delete(fontfam);
+        return -1;
+      }
       gt_graphics_set_font(canvas->pvt->g,
-                           "Sans",
+                           gt_str_get(fontfam),
                            SLANT_NORMAL,
                            WEIGHT_NORMAL,
                            theight);
+      gt_str_delete(fontfam);
       gt_graphics_draw_text_clip(canvas->pvt->g,
                                  block_start,
                                  canvas->pvt->y - bar_height/2
@@ -695,6 +712,7 @@ int gt_canvas_cairo_visit_custom_track(GtCanvas *canvas,
 
   if (show_track_captions)
   {
+    GtStr *fontfam = NULL;
     double theight = gt_graphics_get_text_height(canvas->pvt->g),
            captionspace = CAPTION_BAR_SPACE_DEFAULT;
     if (gt_style_get_num(canvas->pvt->sty,
@@ -702,9 +720,16 @@ int gt_canvas_cairo_visit_custom_track(GtCanvas *canvas,
                          &theight, NULL, err) == GT_STYLE_QUERY_ERROR) {
       return -1;
     }
+    fontfam = gt_str_new_cstr("Sans");
+    if (gt_style_get_str(canvas->pvt->sty,
+                         "format", "track_caption_font_family",
+                         fontfam, NULL, err ) == GT_STYLE_QUERY_ERROR) {
+      gt_str_delete(fontfam);
+      return -1;
+    }
     /* draw track title */
     gt_graphics_set_font(canvas->pvt->g,
-                           "Sans",
+                           gt_str_get(fontfam),
                            SLANT_NORMAL,
                            WEIGHT_NORMAL,
                            theight);
@@ -719,6 +744,7 @@ int gt_canvas_cairo_visit_custom_track(GtCanvas *canvas,
       return -1;
     }
     canvas->pvt->y += theight + captionspace;
+    gt_str_delete(fontfam);
   }
 
   /* call rendering function */
@@ -745,14 +771,14 @@ int gt_canvas_cairo_visit_custom_track(GtCanvas *canvas,
 int gt_canvas_cairo_draw_ruler(GtCanvas *canvas, GtRange viewrange,
                                 GtError *err)
 {
-  double step, minorstep, vmajor, vminor,
+  double step, minorstep, vmajor, vminor, offset,
          theight = gt_graphics_get_text_height(canvas->pvt->g);
   GtWord base_length, tick;
   GtColor rulercol, gridcol;
-  GtStr *left_str, *right_str, *unit;
+  GtStr *left_str = NULL, *right_str = NULL, *unit = NULL, *fontfam = NULL;
   char str[BUFSIZ];
   GtStyleQueryStatus rval;
-  bool showgrid = true;
+  bool showgrid = true, nozeropos = false;
   gt_assert(canvas);
 
   if (gt_style_get_bool(canvas->pvt->sty, "format", "show_grid", &showgrid,
@@ -764,6 +790,19 @@ int gt_canvas_cairo_draw_ruler(GtCanvas *canvas, GtRange viewrange,
     return -1;
   }
 
+  /* get offset value from style, default: 0 */
+  offset = 0;
+  if (gt_style_get_num(canvas->pvt->sty, "format", "ruler_offset",
+                       &offset, NULL, err) == GT_STYLE_QUERY_ERROR) {
+    return -1;
+  }
+
+  nozeropos = false;
+  if (gt_style_get_bool(canvas->pvt->sty, "format", "ruler_nozeropos",
+                        &nozeropos, NULL, err) == GT_STYLE_QUERY_ERROR) {
+    return -1;
+  }
+
   /* get unit value from style, default: empty */
   unit = gt_str_new();
   if (gt_style_get_str(canvas->pvt->sty,
@@ -789,6 +828,7 @@ int gt_canvas_cairo_draw_ruler(GtCanvas *canvas, GtRange viewrange,
     default:
       break;
   }
+
   right_str = gt_str_new();
   rval = gt_style_get_str(canvas->pvt->sty, "format",
                         "ruler_right_text", right_str, NULL, err);
@@ -806,9 +846,20 @@ int gt_canvas_cairo_draw_ruler(GtCanvas *canvas, GtRange viewrange,
       break;
   }
 
+  fontfam = gt_str_new_cstr("Sans");
+  if (gt_style_get_str(canvas->pvt->sty,
+                       "format", "ruler_font_family",
+                       fontfam, NULL, err ) == GT_STYLE_QUERY_ERROR) {
+    gt_str_delete(fontfam);
+    gt_str_delete(unit);
+    gt_str_delete(left_str);
+    gt_str_delete(right_str);
+    return -1;
+  }
+
   /* reset font to default */
   gt_graphics_set_font(canvas->pvt->g,
-                       "Sans",
+                       gt_str_get(fontfam),
                        SLANT_NORMAL,
                        WEIGHT_NORMAL,
                        theight);
@@ -835,6 +886,9 @@ int gt_canvas_cairo_draw_ruler(GtCanvas *canvas, GtRange viewrange,
     double drawtick = (gt_coords_convert_point(viewrange, tick)
                        * (canvas->pvt->width-2*canvas->pvt->margins))
                        + canvas->pvt->margins;
+    GtWord pos = tick + (GtWord)offset;
+    if (pos <= 0 && nozeropos)
+      pos--;
     if (tick < viewrange.start) continue;
     gt_graphics_draw_vertical_line(canvas->pvt->g,
                                    drawtick,
@@ -842,7 +896,7 @@ int gt_canvas_cairo_draw_ruler(GtCanvas *canvas, GtRange viewrange,
                                    rulercol,
                                    10,
                                    1.0);
-    gt_format_ruler_label(str, tick, gt_str_get(unit), BUFSIZ);
+    gt_format_ruler_label(str, pos, gt_str_get(unit), BUFSIZ);
     gt_graphics_draw_text_centered(canvas->pvt->g,
                                    drawtick,
                                    canvas->pvt->y + 20,
@@ -885,7 +939,7 @@ int gt_canvas_cairo_draw_ruler(GtCanvas *canvas, GtRange viewrange,
                                      * canvas->pvt->margins,
                                    1.25);
 
-    gt_graphics_draw_text_right(canvas->pvt->g,
+  gt_graphics_draw_text_right(canvas->pvt->g,
                               canvas->pvt->margins - 10,
                               canvas->pvt->y + 39 + (theight/2),
                               gt_str_get(left_str));
@@ -897,6 +951,7 @@ int gt_canvas_cairo_draw_ruler(GtCanvas *canvas, GtRange viewrange,
   gt_str_delete(unit);
   gt_str_delete(left_str);
   gt_str_delete(right_str);
+  gt_str_delete(fontfam);
 
   return 0;
 }
