@@ -54,7 +54,7 @@
 #define TIME_DATE_FORMAT    "%a, %b %d %Y - %T"
 
 typedef struct {
-  unsigned long width;
+  GtUword width;
   double pwidth, pheight, theight;
   GtRange range;
   GtStr *seqid, *format, *stylefile, *text, *seqfile;
@@ -68,7 +68,7 @@ static void *gt_sketch_page_arguments_new(void)
   arguments->text = gt_str_new();
   arguments->stylefile = gt_str_new();
   arguments->seqfile = gt_str_new();
-  arguments->range.start = arguments->range.end == GT_UNDEF_ULONG;
+  arguments->range.start = arguments->range.end == GT_UNDEF_UWORD;
   return arguments;
 }
 
@@ -124,7 +124,7 @@ static GtOptionParser* gt_sketch_page_option_parser_new(void *tool_arguments)
   gt_option_parser_add_option(op, o);
   gt_option_hide_default(o);
 
-  o = gt_option_new_ulong_min("linewidth", "base width of a single "
+  o = gt_option_new_uword_min("linewidth", "base width of a single "
                                            "repeated unit",
                               &arguments->width, 2000, 1000);
   gt_option_is_mandatory(o);
@@ -177,7 +177,7 @@ static double mm_to_pt(double mm)
 }
 
 static void draw_header(cairo_t *cr, const char *text, GT_UNUSED const char *fn,
-                        const char *seqid, GT_UNUSED unsigned long pagenum,
+                        const char *seqid, GT_UNUSED GtUword pagenum,
                         GT_UNUSED double width, GT_UNUSED double height,
                         double theight)
 {
@@ -213,7 +213,7 @@ static void draw_header(cairo_t *cr, const char *text, GT_UNUSED const char *fn,
   cairo_show_text(cr, seqid);
   xpos = TEXT_SPACER;
   cairo_move_to(cr, xpos, height - 2*TEXT_SPACER - theight);
-  (void) snprintf(buffer, BUFSIZ, "Page %lu", pagenum+1);
+  (void) snprintf(buffer, BUFSIZ, "Page "GT_WU"", pagenum+1);
   cairo_show_text(cr, buffer);
   cairo_restore(cr);
 }
@@ -236,7 +236,7 @@ static int gt_sketch_page_runner(GT_UNUSED int argc,
   GtCanvas *canvas = NULL;
   char *seqid = NULL;
   const char *outfile = NULL;
-  unsigned long start, height, num_pages = 0;
+  GtUword start, height, num_pages = 0;
   double offsetpos, usable_height;
   cairo_surface_t *surf = NULL;
   cairo_t *cr = NULL;
@@ -311,10 +311,10 @@ static int gt_sketch_page_runner(GT_UNUSED int argc,
   }
   if (!had_err)
   {
-    qry_range.start = (arguments->range.start == GT_UNDEF_ULONG ?
+    qry_range.start = (arguments->range.start == GT_UNDEF_UWORD ?
                          sequence_region_range.start :
                          arguments->range.start);
-    qry_range.end   = (arguments->range.end == GT_UNDEF_ULONG ?
+    qry_range.end   = (arguments->range.end == GT_UNDEF_UWORD ?
                          sequence_region_range.end :
                          arguments->range.end);
 
@@ -412,7 +412,7 @@ static int gt_sketch_page_runner(GT_UNUSED int argc,
                 arguments->theight);
     cairo_show_page(cr);
     num_pages++;
-    gt_log_log("finished, should be %lu pages\n", num_pages);
+    gt_log_log("finished, should be "GT_WU" pages\n", num_pages);
     gt_text_width_calculator_delete(twc);
     cairo_destroy(cr);
     cairo_surface_flush(surf);
