@@ -1,6 +1,6 @@
 /*
   Copyright (c) 2007-2012 Sascha Steinbiss <steinbiss@zbh.uni-hamburg.de>
-  Copyright (c) 2008      Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2008      Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2007-2012 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -76,7 +76,7 @@ static char *gt_default_format_style =
 struct GtStyle
 {
   lua_State *L;
-  unsigned long reference_count;
+  GtUword reference_count;
   GtRWLock *lock, *clone_lock;
   bool unsafe;
   char *filename;
@@ -759,7 +759,7 @@ int gt_style_to_str(const GtStyle *sty, GtStr *outstr, GtError *err)
 #ifndef NDEBUG
   int stack_size;
 #endif
-  int had_err;
+  int had_err = 0;
   gt_error_check(err);
   gt_assert(sty && outstr);
   gt_rwlock_wrlock(sty->lock);
@@ -821,7 +821,10 @@ GtStyle* gt_style_clone(const GtStyle *sty, GtError *err)
     had_err = gt_style_load_str(new_sty, sty_buffer, err);
   gt_rwlock_unlock(sty->clone_lock);
   gt_str_delete(sty_buffer);
-  return new_sty;
+  if (had_err) {
+    gt_style_delete(new_sty);
+    return NULL;
+  } else return new_sty;
 }
 
 int gt_style_unit_test(GtError *err)
@@ -846,37 +849,37 @@ int gt_style_unit_test(GtError *err)
   testerr = gt_error_new();
 
   /* instantiate new style object */
-  gt_ensure(had_err, (sty = gt_style_new(testerr)) != NULL);
-  gt_ensure(had_err, !gt_error_is_set(testerr));
+  gt_ensure((sty = gt_style_new(testerr)) != NULL);
+  gt_ensure(!gt_error_is_set(testerr));
 
   /* test safe/unsafe mode switching */
-  gt_ensure(had_err, !gt_style_is_unsafe(sty));
+  gt_ensure(!gt_style_is_unsafe(sty));
   gt_style_unsafe_mode(sty);
-  gt_ensure(had_err, gt_style_is_unsafe(sty));
+  gt_ensure(gt_style_is_unsafe(sty));
   gt_style_safe_mode(sty);
-  gt_ensure(had_err, !gt_style_is_unsafe(sty));
+  gt_ensure(!gt_style_is_unsafe(sty));
 
   /* at the beginning, all values are defaults, since nothing is defined */
-  gt_ensure(had_err, gt_style_get_color(sty, "exon", "fill", &tmpcol, NULL,
+  gt_ensure(gt_style_get_color(sty, "exon", "fill", &tmpcol, NULL,
                                      testerr) != GT_STYLE_QUERY_ERROR);
-  gt_ensure(had_err, gt_color_equals(&tmpcol, &defcol));
-  gt_ensure(had_err, !gt_error_is_set(testerr));
-  gt_ensure(had_err, gt_style_get_color(sty, "cds", "fill", &tmpcol, NULL,
+  gt_ensure(gt_color_equals(&tmpcol, &defcol));
+  gt_ensure(!gt_error_is_set(testerr));
+  gt_ensure(gt_style_get_color(sty, "cds", "fill", &tmpcol, NULL,
                                      testerr) != GT_STYLE_QUERY_ERROR);
-  gt_ensure(had_err, gt_color_equals(&tmpcol, &defcol));
-  gt_ensure(had_err, !gt_error_is_set(testerr));
-  gt_ensure(had_err, gt_style_get_color(sty, "foo", "fill", &tmpcol, NULL,
+  gt_ensure(gt_color_equals(&tmpcol, &defcol));
+  gt_ensure(!gt_error_is_set(testerr));
+  gt_ensure(gt_style_get_color(sty, "foo", "fill", &tmpcol, NULL,
                                      testerr) != GT_STYLE_QUERY_ERROR);
-  gt_ensure(had_err, gt_color_equals(&tmpcol, &defcol));
-  gt_ensure(had_err, !gt_error_is_set(testerr));
-  gt_ensure(had_err, gt_style_get_num(sty, "format", "margins", &num, NULL,
+  gt_ensure(gt_color_equals(&tmpcol, &defcol));
+  gt_ensure(!gt_error_is_set(testerr));
+  gt_ensure(gt_style_get_num(sty, "format", "margins", &num, NULL,
                                    testerr) != GT_STYLE_QUERY_ERROR);
-  gt_ensure(had_err, !gt_error_is_set(testerr));
-  gt_ensure(had_err, num == MARGINS_DEFAULT);
-  gt_ensure(had_err, gt_style_get_bool(sty, "exon", "collapse_to_parent", &val,
+  gt_ensure(!gt_error_is_set(testerr));
+  gt_ensure(num == MARGINS_DEFAULT);
+  gt_ensure(gt_style_get_bool(sty, "exon", "collapse_to_parent", &val,
                                     NULL, testerr) != GT_STYLE_QUERY_ERROR);
-  gt_ensure(had_err, !gt_error_is_set(testerr));
-  gt_ensure(had_err, !val);
+  gt_ensure(!gt_error_is_set(testerr));
+  gt_ensure(!val);
 
   /* change some values... */
   (void) gt_style_set_color(sty, "exon", "fill", &col1);
@@ -885,55 +888,55 @@ int gt_style_unit_test(GtError *err)
 
   /* is it saved correctly? */
   (void) gt_style_get_color(sty, "exon", "fill", &tmpcol, NULL, testerr);
-  gt_ensure(had_err, !gt_color_equals(&tmpcol, &defcol));
-  gt_ensure(had_err, gt_color_equals(&tmpcol, &col1));
-  gt_ensure(had_err, gt_style_get_num(sty, "format", "margins", &num, NULL,
+  gt_ensure(!gt_color_equals(&tmpcol, &defcol));
+  gt_ensure(gt_color_equals(&tmpcol, &col1));
+  gt_ensure(gt_style_get_num(sty, "format", "margins", &num, NULL,
                                    testerr) != GT_STYLE_QUERY_ERROR);
-  gt_ensure(had_err, num == 11.0);
-  gt_ensure(had_err, !gt_error_is_set(testerr));
-  gt_ensure(had_err, gt_style_get_num(sty, "format", "foo", &num, NULL,
+  gt_ensure(num == 11.0);
+  gt_ensure(!gt_error_is_set(testerr));
+  gt_ensure(gt_style_get_num(sty, "format", "foo", &num, NULL,
                                    testerr) != GT_STYLE_QUERY_ERROR);
-  gt_ensure(had_err, num == 2.0);
-  gt_ensure(had_err, !gt_error_is_set(testerr));
+  gt_ensure(num == 2.0);
+  gt_ensure(!gt_error_is_set(testerr));
 
   /* create a new color definition */
   gt_style_set_color(sty, "foo", "fill", &col2);
   gt_style_set_str(sty, "bar", "baz", test1);
 
   /* is it saved correctly? */
-  gt_ensure(had_err, gt_style_get_color(sty, "foo", "fill", &tmpcol, NULL,
+  gt_ensure(gt_style_get_color(sty, "foo", "fill", &tmpcol, NULL,
                                      testerr) != GT_STYLE_QUERY_ERROR);
-  gt_ensure(had_err, !gt_color_equals(&tmpcol, &defcol));
-  gt_ensure(had_err, gt_color_equals(&tmpcol, &col2));
+  gt_ensure(!gt_color_equals(&tmpcol, &defcol));
+  gt_ensure(gt_color_equals(&tmpcol, &col2));
   gt_str_reset(str);
-  gt_ensure(had_err, gt_style_get_str(sty, "bar", "baz", str, NULL,
+  gt_ensure(gt_style_get_str(sty, "bar", "baz", str, NULL,
                                    testerr) != GT_STYLE_QUERY_ERROR);
-  gt_ensure(had_err, (strcmp(gt_str_get(str),"")!=0));
-  gt_ensure(had_err, (gt_str_cmp(str,test1)==0));
+  gt_ensure((strcmp(gt_str_get(str),"")!=0));
+  gt_ensure((gt_str_cmp(str,test1)==0));
   gt_str_reset(str);
-  gt_ensure(had_err, gt_style_get_str(sty, "bar", "test", str, NULL,
+  gt_ensure(gt_style_get_str(sty, "bar", "test", str, NULL,
                                    testerr) != GT_STYLE_QUERY_ERROR);
-  gt_ensure(had_err, (strcmp(gt_str_get(str),"")==0));
+  gt_ensure((strcmp(gt_str_get(str),"")==0));
 
   /* clone a GtStyle object */
   new_sty = gt_style_clone(sty, testerr);
-  gt_ensure(had_err, new_sty  != NULL);
-  gt_ensure(had_err, !gt_error_is_set(testerr));
+  gt_ensure(new_sty  != NULL);
+  gt_ensure(!gt_error_is_set(testerr));
 
   /* check again */
-  gt_ensure(had_err, gt_style_get_color(new_sty, "foo", "fill", &tmpcol, NULL,
+  gt_ensure(gt_style_get_color(new_sty, "foo", "fill", &tmpcol, NULL,
                                      testerr) == 0);
-  gt_ensure(had_err, !gt_color_equals(&tmpcol, &defcol));
-  gt_ensure(had_err, gt_color_equals(&tmpcol, &col2));
+  gt_ensure(!gt_color_equals(&tmpcol, &defcol));
+  gt_ensure(gt_color_equals(&tmpcol, &col2));
   gt_str_reset(str);
-  gt_ensure(had_err, gt_style_get_str(new_sty, "bar", "baz", str, NULL,
+  gt_ensure(gt_style_get_str(new_sty, "bar", "baz", str, NULL,
                                    testerr) != GT_STYLE_QUERY_ERROR);
-  gt_ensure(had_err, (strcmp(gt_str_get(str),"")!=0));
-  gt_ensure(had_err, (gt_str_cmp(str,test1)==0));
+  gt_ensure((strcmp(gt_str_get(str),"")!=0));
+  gt_ensure((gt_str_cmp(str,test1)==0));
   gt_str_reset(str);
-  gt_ensure(had_err, gt_style_get_str(new_sty, "bar", "test", str, NULL,
+  gt_ensure(gt_style_get_str(new_sty, "bar", "test", str, NULL,
                                    testerr) != GT_STYLE_QUERY_ERROR);
-  gt_ensure(had_err, (strcmp(gt_str_get(str),"")==0));
+  gt_ensure((strcmp(gt_str_get(str),"")==0));
 
   /* mem cleanup */
   gt_error_delete(testerr);
