@@ -23,7 +23,7 @@
 #include "core/ma.h"
 #include "core/msort.h"
 #include "core/mathsupport.h"
-#include "core/qsort_r.h"
+#include "core/qsort_r_api.h"
 #include "core/range.h"
 #include "core/unused_api.h"
 
