@@ -196,6 +196,25 @@ static int gt_bioseq_col_grep_desc_md5(GtSeqCol *sc, const char **md5,
   return had_err;
 }
 
+static int gt_bioseq_col_grep_desc_desc(GtSeqCol *sc, GtStr *desc,
+                                        GtStr *seqid, GtError *err)
+{
+  GtUword filenum = 0, seqnum = 0;
+  int had_err;
+  GtBioseqCol *bsc;
+  bsc = gt_bioseq_col_cast(sc);
+  gt_error_check(err);
+  gt_assert(bsc && desc && seqid);
+  had_err = grep_desc(bsc, &filenum, &seqnum, seqid, err);
+  if (!had_err) {
+    const char *mydesc = gt_bioseq_get_description(bsc->bioseqs[filenum],
+                                                   seqnum);
+    if (mydesc)
+      gt_str_append_cstr(desc, mydesc);
+  }
+  return had_err;
+}
+
 static int gt_bioseq_col_grep_desc_sequence_length(GtSeqCol *sc,
                                                    GtUword *length,
                                                    GtStr *seqid,
@@ -375,6 +394,7 @@ const GtSeqColClass* gt_bioseq_col_class(void)
                                        gt_bioseq_col_delete,
                                        gt_bioseq_col_enable_match_desc_start,
                                        gt_bioseq_col_grep_desc,
+                                       gt_bioseq_col_grep_desc_desc,
                                        gt_bioseq_col_grep_desc_md5,
                                        gt_bioseq_col_grep_desc_sequence_length,
                                        gt_bioseq_col_md5_to_seq,
