@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2008 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2006-2008 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2006-2008 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -30,7 +30,7 @@ struct GtDlist {
   GtDlistelem *first,
               *last;
   void *data;
-  unsigned long size;
+  GtUword size;
 };
 
 struct GtDlistelem {
@@ -91,7 +91,7 @@ GtDlistelem* gt_dlist_find(const GtDlist *dlist, void *new_data)
   return NULL;
 }
 
-unsigned long gt_dlist_size(const GtDlist *dlist)
+GtUword gt_dlist_size(const GtDlist *dlist)
 {
   return dlist ? dlist->size : 0;
 }
@@ -217,25 +217,25 @@ int gt_dlist_unit_test(GtError *err)
 
   /* boundary case: empty dlist */
   dlist = gt_dlist_new(intcompare);
-  gt_ensure(had_err, !gt_dlist_size(dlist));
+  gt_ensure(!gt_dlist_size(dlist));
   gt_dlist_delete(dlist);
 
   dlist = gt_dlist_new(NULL);
-  gt_ensure(had_err, !gt_dlist_size(dlist));
+  gt_ensure(!gt_dlist_size(dlist));
   gt_dlist_delete(dlist);
 
   /* boundary case: dlist containing one element */
   dlist = gt_dlist_new(intcompare);
   gt_dlist_add(dlist, &elem_a);
-  gt_ensure(had_err, gt_dlist_size(dlist) == 1);
-  gt_ensure(had_err,
+  gt_ensure(gt_dlist_size(dlist) == 1);
+  gt_ensure(
          elem_a == *(int*) gt_dlistelem_get_data(gt_dlist_first(dlist)));
   gt_dlist_delete(dlist);
 
   dlist = gt_dlist_new(NULL);
   gt_dlist_add(dlist, &elem_a);
-  gt_ensure(had_err, gt_dlist_size(dlist) == 1);
-  gt_ensure(had_err,
+  gt_ensure(gt_dlist_size(dlist) == 1);
+  gt_ensure(
          elem_a == *(int*) gt_dlistelem_get_data(gt_dlist_first(dlist)));
   gt_dlist_delete(dlist);
 
@@ -243,16 +243,16 @@ int gt_dlist_unit_test(GtError *err)
   dlist = gt_dlist_new(intcompare);
   gt_dlist_add(dlist, &elem_a);
   gt_dlist_add(dlist, &elem_b);
-  gt_ensure(had_err, gt_dlist_size(dlist) == 2);
-  gt_ensure(had_err,
+  gt_ensure(gt_dlist_size(dlist) == 2);
+  gt_ensure(
          elem_b == *(int*) gt_dlistelem_get_data(gt_dlist_first(dlist)));
   gt_dlist_delete(dlist);
 
   dlist = gt_dlist_new(NULL);
   gt_dlist_add(dlist, &elem_a);
   gt_dlist_add(dlist, &elem_b);
-  gt_ensure(had_err, gt_dlist_size(dlist) == 2);
-  gt_ensure(had_err,
+  gt_ensure(gt_dlist_size(dlist) == 2);
+  gt_ensure(
          elem_a == *(int*) gt_dlistelem_get_data(gt_dlist_first(dlist)));
   gt_dlist_delete(dlist);
 
@@ -269,10 +269,10 @@ int gt_dlist_unit_test(GtError *err)
 
     /* test with compare function */
     dlist = gt_dlist_new(intcompare);
-    gt_ensure(had_err, !gt_dlist_size(dlist));
+    gt_ensure(!gt_dlist_size(dlist));
     for (j = 0; j < size && !had_err; j++) {
       gt_dlist_add(dlist, elems + j);
-      gt_ensure(had_err, gt_dlist_size(dlist) == j+1);
+      gt_ensure(gt_dlist_size(dlist) == j+1);
 
       for (dlistelem = gt_dlist_first(dlist); dlistelem != NULL;
            dlistelem = gt_dlistelem_next(dlistelem)) {
@@ -282,14 +282,14 @@ int gt_dlist_unit_test(GtError *err)
     for (dlistelem = gt_dlist_first(dlist); dlistelem != NULL;
          dlistelem = gt_dlistelem_next(dlistelem)) {
       data = gt_dlistelem_get_data(dlistelem);
-      gt_ensure(had_err, *data == elems_backup[j]);
+      gt_ensure(*data == elems_backup[j]);
       j++;
     }
     /* test gt_dlist_find() */
     for (j = 0; j < size; j++) {
       dlistelem = gt_dlist_find(dlist, elems_backup + j);
-      gt_ensure(had_err, dlistelem);
-      gt_ensure(had_err,
+      gt_ensure(dlistelem);
+      gt_ensure(
              *(int*) gt_dlistelem_get_data(dlistelem) == elems_backup[j]);
     }
     /* remove first element */
@@ -297,7 +297,7 @@ int gt_dlist_unit_test(GtError *err)
       gt_dlist_remove(dlist, gt_dlist_first(dlist));
       if (gt_dlist_size(dlist)) {
         data = gt_dlistelem_get_data(gt_dlist_first(dlist));
-        gt_ensure(had_err, *data == elems_backup[1]);
+        gt_ensure(*data == elems_backup[1]);
       }
     }
     /* remove last element */
@@ -305,7 +305,7 @@ int gt_dlist_unit_test(GtError *err)
       gt_dlist_remove(dlist, gt_dlist_last(dlist));
       if (gt_dlist_size(dlist)) {
         data = gt_dlistelem_get_data(gt_dlist_last(dlist));
-        gt_ensure(had_err, *data == elems_backup[size - 2]);
+        gt_ensure(*data == elems_backup[size - 2]);
       }
     }
     /* XXX: fix this */
@@ -320,23 +320,24 @@ int gt_dlist_unit_test(GtError *err)
       for (j = 1; j < gt_dlist_size(dlist) / 2 + 1; j++)
         dlistelem = gt_dlistelem_next(dlistelem);
       data = gt_dlistelem_get_data(gt_dlist_last(dlist));
-      gt_ensure(had_err, *data == elems_backup[size / 2 + 1]);
+      gt_ensure(*data == elems_backup[size / 2 + 1]);
     }
 #endif
     gt_dlist_delete(dlist);
 
     /* test without compare function */
     dlist = gt_dlist_new(NULL);
-    gt_ensure(had_err, !gt_dlist_size(dlist));
+    gt_ensure(!gt_dlist_size(dlist));
     for (j = 0; j < size && !had_err; j++) {
       gt_dlist_add(dlist, elems + j);
-      gt_ensure(had_err, gt_dlist_size(dlist) == j+1);
+      gt_ensure(gt_dlist_size(dlist) == j+1);
     }
     j = 0;
     for (dlistelem = gt_dlist_first(dlist); dlistelem != NULL;
          dlistelem = gt_dlistelem_next(dlistelem)) {
       data = gt_dlistelem_get_data(dlistelem);
-      gt_ensure(had_err, *data == elems[j]);
+      gt_assert(j < MAX_SIZE);
+      gt_ensure(*data == elems[j]);
       j++;
     }
     /* remove first element */
@@ -344,7 +345,7 @@ int gt_dlist_unit_test(GtError *err)
       gt_dlist_remove(dlist, gt_dlist_first(dlist));
       if (gt_dlist_size(dlist)) {
         data = gt_dlistelem_get_data(gt_dlist_first(dlist));
-        gt_ensure(had_err, *data == elems[1]);
+        gt_ensure(*data == elems[1]);
       }
     }
     /* remove last element */
@@ -352,7 +353,7 @@ int gt_dlist_unit_test(GtError *err)
       gt_dlist_remove(dlist, gt_dlist_last(dlist));
       if (gt_dlist_size(dlist)) {
         data = gt_dlistelem_get_data(gt_dlist_last(dlist));
-        gt_ensure(had_err, *data == elems[size - 2]);
+        gt_ensure(*data == elems[size - 2]);
       }
     }
     gt_dlist_delete(dlist);
