@@ -23,6 +23,7 @@
 #include "core/divmodmul.h"
 #include "core/ma_api.h"
 #include "core/safecast-gen.h"
+#include "core/types_api.h"
 
 /*
   This file contains some definitions manipulating bitvectors represented
@@ -30,7 +31,7 @@
   and \texttt{\symbol{94}} for exponentiation of the previous character.
 */
 
-#ifdef _LP64
+#if defined (_LP64) || defined (_WIN64)
 
 #define GT_LOGWORDSIZE    6         /* base 2 logarithm of wordsize */
 typedef uint64_t GtBitsequence;
@@ -44,7 +45,7 @@ typedef uint32_t GtBitsequence;
 #define GT_WORDSIZE_INBYTES (sizeof (void *))
 
 #define GT_INTWORDSIZE\
-        (1 << GT_LOGWORDSIZE) /* # of bits in unsigned long = w */
+        (1 << GT_LOGWORDSIZE) /* # of bits in GtUword = w */
 #define GT_LASTHALVEBITS\
         ((((GtBitsequence) 1) << GT_DIV2(GT_INTWORDSIZE)) - 1)
 #define GT_FIRSTHALVEBITS\
@@ -94,7 +95,6 @@ typedef GtBitsequence GtTwobitencoding;
 /*
   The following defines the number of integers for a bitvector with N bits.
 */
-
 #define GT_NUMOFINTSFORBITS(N)\
         ((GT_DIVWORDSIZE(N) == 0)\
            ? (size_t) 1 \
@@ -104,7 +104,6 @@ typedef GtBitsequence GtTwobitencoding;
   The following macro allocates a bitarray of \texttt{N} bits. All bits
   are off.
 */
-
 #define GT_INITBITTABGENERIC(TAB,OLDTAB,NUMOFBITS)\
         {\
           size_t tabsize = GT_NUMOFINTSFORBITS(NUMOFBITS);\
@@ -118,7 +117,6 @@ typedef GtBitsequence GtTwobitencoding;
   The following macro inititalizes a bitarray such that all bits
   are off.
 */
-
 #define GT_CLEARBITTAB(TAB,N)\
         (void) memset(TAB,0,sizeof (GtBitsequence) * GT_NUMOFINTSFORBITS(N))
 
@@ -126,7 +124,6 @@ typedef GtBitsequence GtTwobitencoding;
   \texttt{SETIBIT(TAB,I)} sets the \texttt{I}-th bit in bitarray
   \texttt{TAB} to 1.
 */
-
 #define GT_SETIBIT(TAB,I)    (TAB)[GT_DIVWORDSIZE(I)] |= \
                                     GT_ITHBIT(GT_MODWORDSIZE(I))
 
@@ -134,7 +131,6 @@ typedef GtBitsequence GtTwobitencoding;
   \texttt{UNSSETIBIT(TAB,I)} sets the \texttt{I}-th bit in bitarray
   \texttt{TAB} to 0.
 */
-
 #define GT_UNSETIBIT(TAB,I)  (TAB)[GT_DIVWORDSIZE(I)] &= \
                                      ~(GT_ITHBIT(GT_MODWORDSIZE(I)))
 
@@ -142,7 +138,6 @@ typedef GtBitsequence GtTwobitencoding;
   \texttt{ISIBITSET(TAB,I)} checks if the \texttt{I}-th bit in bitarray
   \texttt{TAB} is 1.
 */
-
 #define GT_ISIBITSET(TAB,I)  ((TAB)[GT_DIVWORDSIZE(I)] & \
                                     GT_ITHBIT(GT_MODWORDSIZE(I)))
 
@@ -150,7 +145,6 @@ typedef GtBitsequence GtTwobitencoding;
   \texttt{BITNUM2WORD(TAB,I)} delivers the integer containing
   the \texttt{I}-th bit.
 */
-
 #define GT_BITNUM2WORD(TAB,I)  (TAB)[GT_DIVWORDSIZE(I)]
 
 /*@unused@*/ static inline void gt_byte2string(char *buffer, unsigned char bs)
@@ -197,12 +191,12 @@ static inline void gt_bitsequence_tostring_units(char *buffer,
   buffer[idx] = '\0';
 }
 
-/*@unused@*/ static inline unsigned long gt_unitsoftwobitencoding(unsigned long
+/*@unused@*/ static inline GtUword gt_unitsoftwobitencoding(GtUword
                                                                   totallength)
 {
   uint64_t unitsoftwobitencoding;
 
-  if (totallength < (unsigned long) GT_UNITSIN2BITENC) {
+  if (totallength < (GtUword) GT_UNITSIN2BITENC) {
     return 2UL;
   }
   unitsoftwobitencoding = (uint64_t) (2 +
@@ -223,7 +217,7 @@ static const unsigned char ReversedByte[256] =
   GtBitsequence out;
   unsigned char *q = (unsigned char*) &out;
   unsigned char *p = (unsigned char*) &bs;
-#ifdef _LP64
+#if defined (_LP64) || defined (_WIN64)
   q[7] = ReversedByte[p[0]];
   q[6] = ReversedByte[p[1]];
   q[5] = ReversedByte[p[2]];
@@ -244,7 +238,7 @@ static const unsigned char ReversedByte[256] =
 /*@unused@*/
 static inline GtBitsequence gt_intbits_reverse_unitwise(GtBitsequence bs)
 {
-#ifdef _LP64
+#if defined (_LP64) || defined (_WIN64)
   /* 10 shifts, 10 &, 5 |, 4 assignments = 29 ops */
   bs = (bs & 0xFFFFFFFF00000000) >> 32 | (bs & 0x00000000FFFFFFFF) << 32;
   bs = (bs & 0xFFFF0000FFFF0000) >> 16 | (bs & 0x0000FFFF0000FFFF) << 16;
