@@ -26,8 +26,9 @@
 #include <stdlib.h>
 #include <stdio.h>
 
-#include "core/md5_encoder_api.h"
 #include "core/assert_api.h"
+#include "core/ma.h"
+#include "core/md5_encoder_api.h"
 
 #define GT_MD5_WORD 32
 #define GT_MD5_MASK 0xFFFFFFFF
@@ -186,13 +187,13 @@ struct GtMD5Encoder {
   WORD32 d[4];
   WORD32 d_old[4];
   WORD32 wbuff[16];
-  unsigned long len;
+  GtUword len;
   int status;
 };
 
 GtMD5Encoder* gt_md5_encoder_new()
 {
-  GtMD5Encoder *enc = malloc(sizeof (GtMD5Encoder));
+  GtMD5Encoder *enc = gt_malloc(sizeof (GtMD5Encoder));
   enc->len = 0;
   enc->status = 0;
   memset(enc->d_old, 0, sizeof (WORD32)*4);
@@ -212,7 +213,7 @@ void gt_md5_encoder_reset(GtMD5Encoder *enc)
 }
 
 void gt_md5_encoder_add_block(GtMD5Encoder *enc, const char *message,
-                              unsigned long len)
+                              GtUword len)
 {
   gt_assert(enc && message && len < 65);
   if (enc->len > 0) {
@@ -258,5 +259,5 @@ void gt_md5_encoder_finish(GtMD5Encoder *enc, unsigned char *output,
 void gt_md5_encoder_delete(GtMD5Encoder *enc)
 {
   if (!enc) return;
-  free(enc);
+  gt_free(enc);
 }
