@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2010 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2006-2010 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2006-2008 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -20,5 +20,10 @@
 
 bool gt_process_is_foreground(void)
 {
+#ifndef _WIN32
   return getpgrp() == tcgetpgrp(STDOUT_FILENO);
+#else
+  /* XXX */
+  return true;
+#endif
 }
