@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2010, 2012 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2010, 2012 Gordon Gremme <gordon@gremme.org>
 
   Permission to use, copy, modify, and distribute this software for any
   purpose with or without fee is hereby granted, provided that the above
@@ -42,7 +42,7 @@ static int check_cds_phases(GtArray *cds_features, GtCDSCheckVisitor *v,
   GtPhase current_phase, correct_phase = GT_PHASE_ZERO;
   GtFeatureNode *fn;
   GtStrand strand;
-  unsigned long i, current_length;
+  GtUword i, current_length;
   int had_err = 0;
   gt_error_check(err);
   gt_assert(cds_features);
@@ -204,13 +204,14 @@ static GtArray* find_cds_parents(GtFeatureNode *cds_feature, GtFeatureNode *fn)
 static void split_cds_feature(GtFeatureNode *cds_feature, GtFeatureNode *fn)
 {
   GtArray *parents;
-  unsigned long i;
+  GtUword i;
   gt_assert(cds_feature && fn);
 
   /* find parents */
   parents = find_cds_parents(cds_feature, fn);
 
   /* remove CDS feature */
+  gt_genome_node_ref((GtGenomeNode*) cds_feature);
   gt_feature_node_remove_leaf(fn, cds_feature);
 
   /* add CDS feature to all parents */
@@ -225,7 +226,6 @@ static void split_cds_feature(GtFeatureNode *cds_feature, GtFeatureNode *fn)
       GtFeatureNode *new_cds = gt_feature_node_clone(cds_feature);
       gt_feature_node_set_attribute(new_cds, GT_GFF_PARENT, id);
       gt_feature_node_add_child(parent, new_cds);
-      gt_genome_node_delete((GtGenomeNode*) cds_feature);
     }
   }
 
@@ -235,7 +235,7 @@ static void split_cds_feature(GtFeatureNode *cds_feature, GtFeatureNode *fn)
 static void split_cds_features(GtHashmap *features_to_split, GtFeatureNode *fn)
 {
   GtArray *cds_features;
-  unsigned long i;
+  GtUword i;
   GT_UNUSED int had_err;
   gt_assert(features_to_split && fn);
   cds_features = gt_array_new(sizeof (GtFeatureNode*));
