@@ -1,5 +1,5 @@
 /*
-  Copyright (c)       2007 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c)       2007 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2004       Stefan Kurtz <kurtz@zbh.uni-hamburg.de>
   Copyright (c) 2004, 2007 Center for Bioinformatics, University of Hamburg
 
@@ -23,15 +23,14 @@
 
 typedef struct GtChain GtChain;
 
-GtChain*      gt_chain_new(void);
-void          gt_chain_reset(GtChain*);
-long          gt_chain_get_score(const GtChain*);
-void          gt_chain_set_score(GtChain*, long);
-void          gt_chain_add_fragnum(GtChain*, unsigned long fragnum);
-void          gt_chain_set_fragnum(GtChain*, unsigned long idx,
-                                             unsigned long fragnum);
-unsigned long gt_chain_get_fragnum(const GtChain*, unsigned long idx);
-unsigned long gt_chain_size(const GtChain*);
-void          gt_chain_delete(GtChain*);
+GtChain* gt_chain_new(void);
+void     gt_chain_reset(GtChain*);
+GtWord   gt_chain_get_score(const GtChain*);
+void     gt_chain_set_score(GtChain*, GtWord);
+void     gt_chain_add_fragnum(GtChain*, GtUword fragnum);
+void     gt_chain_set_fragnum(GtChain*, GtUword idx, GtUword fragnum);
+GtUword  gt_chain_get_fragnum(const GtChain*, GtUword idx);
+GtUword  gt_chain_size(const GtChain*);
+void     gt_chain_delete(GtChain*);
 
 #endif
