@@ -471,7 +471,9 @@ static int ces_c_xdrop(GtCondenseqCreator *ces_c,
 
   /* left xdrop */
   if (seed_bounds.start < j && match_bounds.start < i) {
-    gt_seqabstract_reinit_encseq(xdrop->unique_seq_bwd,
+    gt_seqabstract_reinit_encseq(!forward,
+                                 GT_READMODE_FORWARD,
+                                 xdrop->unique_seq_bwd,
                                  ces_c->input_es,
                                  i - match_bounds.start,
                                  match_bounds.start);
@@ -485,7 +487,9 @@ static int ces_c_xdrop(GtCondenseqCreator *ces_c,
   }
   /* right xdrop (i < match_bounds.end by assertion) */
   if (j < seed_bounds.end) {
-    gt_seqabstract_reinit_encseq(xdrop->unique_seq_fwd,
+    gt_seqabstract_reinit_encseq(forward,
+                                 GT_READMODE_FORWARD,
+                                 xdrop->unique_seq_fwd,
                                  ces_c->input_es,
                                  match_bounds.end - i,
                                  i);
@@ -564,7 +568,9 @@ static int ces_c_extend_seeds_window(GtCondenseqCreator *ces_c,
   const unsigned int max_win_idx = ces_c->windowsize - 1;
   unsigned int idx_win;
   GtXdropbest empty = {0,0,0,0,0};
-  match_bounds.end = 0;
+  const bool forward = true;
+  match_bounds.end =
+    match_bounds.start = 0;
 
   *xdrop->left = empty;
   *xdrop->right = empty;
@@ -598,13 +604,17 @@ static int ces_c_extend_seeds_window(GtCondenseqCreator *ces_c,
     }
 
     if (seed_bounds.start < querypos) {
-      gt_seqabstract_reinit_encseq(xdrop->current_seq_bwd,
+      gt_seqabstract_reinit_encseq(!forward,
+                                   GT_READMODE_FORWARD,
+                                   xdrop->current_seq_bwd,
                                    ces_c->input_es,
                                    querypos - seed_bounds.start,
                                    seed_bounds.start);
     }
     if (querypos < seed_bounds.end) {
-      gt_seqabstract_reinit_encseq(xdrop->current_seq_fwd,
+      gt_seqabstract_reinit_encseq(forward,
+                                   GT_READMODE_FORWARD,
+                                   xdrop->current_seq_fwd,
                                    ces_c->input_es,
                                    seed_bounds.end - querypos,
                                    querypos);
@@ -696,12 +706,14 @@ static int ces_c_extend_seeds_brute_force(GtCondenseqCreator *ces_c,
   GtUword best_match = GT_UNDEF_UWORD,
           idx_cur,
           j = ces_c->main_pos;
+  const bool forward = true;
   GtXdropbest empty = {0,0,0,0,0};
 
   *xdrop->left = empty;
   *xdrop->right = empty;
 
-  match_bounds.end = 0;
+  match_bounds.end =
+    match_bounds.start = 0;
 
   match_positions = win->pos_arrs[GT_CONDENSEQ_CREATOR_LAST_WIN(win)];
 
@@ -713,13 +725,17 @@ static int ces_c_extend_seeds_brute_force(GtCondenseqCreator *ces_c,
   seed_bounds.end = ces_c->current_seq_start + ces_c->current_seq_len;
 
   if (seed_bounds.start < j) {
-    gt_seqabstract_reinit_encseq(xdrop->current_seq_bwd,
+    gt_seqabstract_reinit_encseq(!forward,
+                                 GT_READMODE_FORWARD,
+                                 xdrop->current_seq_bwd,
                                  ces_c->input_es,
                                  j - seed_bounds.start,
                                  seed_bounds.start);
   }
   if (j < seed_bounds.end) {
-    gt_seqabstract_reinit_encseq(xdrop->current_seq_fwd,
+    gt_seqabstract_reinit_encseq(forward,
+                                 GT_READMODE_FORWARD,
+                                 xdrop->current_seq_fwd,
                                  ces_c->input_es,
                                  seed_bounds.end - j,
                                  j);
@@ -774,6 +790,7 @@ static int ces_c_extend_seeds_diags(GtCondenseqCreator *ces_c,
           i_idx, j,
           old_mid_i = GT_UNDEF_UWORD;
   GtXdropbest empty = {0,0,0,0,0};
+  const bool forward = true;
 
   *xdrop->left = empty;
   *xdrop->right = empty;
@@ -860,14 +877,18 @@ static int ces_c_extend_seeds_diags(GtCondenseqCreator *ces_c,
           if (old_mid_i != midpoint_seed_i) {
             old_mid_i = midpoint_seed_i;
             if (seed_bounds.start < midpoint_seed_j) {
-              gt_seqabstract_reinit_encseq(xdrop->current_seq_bwd,
+              gt_seqabstract_reinit_encseq(!forward,
+                                           GT_READMODE_FORWARD,
+                                           xdrop->current_seq_bwd,
                                            ces_c->input_es,
                                            midpoint_seed_j -
                                            seed_bounds.start,
                                            seed_bounds.start);
             }
             if (midpoint_seed_j < seed_bounds.end) {
-              gt_seqabstract_reinit_encseq(xdrop->current_seq_fwd,
+              gt_seqabstract_reinit_encseq(forward,
+                                           GT_READMODE_FORWARD,
+                                           xdrop->current_seq_fwd,
                                            ces_c->input_es,
                                            seed_bounds.end - midpoint_seed_j,
                                            midpoint_seed_j);
@@ -1188,20 +1209,20 @@ ces_c_reset_pos_and_iter_to_current_seq(GtCondenseqCreator *ces_c)
 static CesCState ces_c_skip_short_seqs(GtCondenseqCreator *ces_c)
 {
 
-  if (ces_c->main_seqnum < ces_c->ces->orig_num_seq) {
-    ces_c->current_seq_len = gt_condenseq_seqlength(ces_c->ces,
-                                                    ces_c->main_seqnum);
-  }
-  while (ces_c->main_seqnum < ces_c->ces->orig_num_seq &&
-         ces_c->current_seq_len < ces_c->min_align_len) {
-    GtUword start = gt_condenseq_seqstartpos(ces_c->ces,
-                                             ces_c->main_seqnum);
-    /* no check necessary, as minalignlength was checked */
-    gt_condenseq_add_unique_to_db(ces_c->ces, start,
-                                  ces_c->current_seq_len);
-    ces_c->main_seqnum++;
+  while (ces_c->main_seqnum < ces_c->ces->orig_num_seq) {
     ces_c->current_seq_len = gt_condenseq_seqlength(ces_c->ces,
                                                     ces_c->main_seqnum);
+    if (ces_c->current_seq_len < ces_c->min_align_len) {
+      GtUword start = gt_condenseq_seqstartpos(ces_c->ces,
+                                               ces_c->main_seqnum);
+      /* no check for overflow of length necessary, as minalignlength was
+         checked not to overflow */
+      gt_condenseq_add_unique_to_db(ces_c->ces, start,
+                                    ces_c->current_seq_len);
+      ces_c->main_seqnum++;
+    }
+    else
+      break;
   }
   return ces_c->main_seqnum >= ces_c->ces->orig_num_seq ?
     GT_CONDENSEQ_CREATOR_EOD : GT_CONDENSEQ_CREATOR_CONT;
@@ -1796,5 +1817,6 @@ int gt_condenseq_creator_create(GtCondenseqCreator *condenseq_creator,
   condenseq_creator->kmer_db = NULL;
   if (gt_showtime_enabled())
     gt_timer_show_progress_final(timer, stderr);
+  gt_timer_delete(timer);
   return had_err;
 }
