@@ -21,8 +21,9 @@
 #include "core/array.h"
 #include "core/ensure.h"
 #include "core/ma.h"
-#include "core/thread_api.h"
+#include "core/multithread_api.h"
 #include "core/unused_api.h"
+#include "core/yarandom.h"
 #include "extended/feature_index_rep.h"
 #include "extended/feature_node.h"
 #ifdef GT_THREADS_ENABLED
@@ -43,6 +44,7 @@ struct GtFeatureIndexClass {
   GtFeatureIndexSaveFunc save_func;
   GtFeatureIndexGetSeqidsFunc get_seqids;
   GtFeatureIndexGetRangeForSeqidFunc get_range_for_seqid;
+  GtFeatureIndexGetOrigRangeForSeqidFunc get_orig_range_for_seqid;
   GtFeatureIndexHasSeqidFunc has_seqid;
   GtFeatureIndexFreeFunc free;
 };
@@ -71,6 +73,8 @@ const GtFeatureIndexClass* gt_feature_index_class_new(size_t size,
                                                  get_seqids,
                                          GtFeatureIndexGetRangeForSeqidFunc
                                                  get_range_for_seqid,
+                                         GtFeatureIndexGetOrigRangeForSeqidFunc
+                                                 get_orig_range_for_seqid,
                                          GtFeatureIndexHasSeqidFunc
                                                  has_seqid,
                                          GtFeatureIndexFreeFunc
@@ -87,6 +91,7 @@ const GtFeatureIndexClass* gt_feature_index_class_new(size_t size,
   c_class->save_func = save_func;
   c_class->get_seqids = get_seqids;
   c_class->get_range_for_seqid = get_range_for_seqid;
+  c_class->get_orig_range_for_seqid = get_orig_range_for_seqid;
   c_class->has_seqid = has_seqid;
   c_class->free = free;
   return c_class;
@@ -174,7 +179,7 @@ int gt_feature_index_add_gff3file(GtFeatureIndex *feature_index,
   GtGenomeNode *gn;
   GtArray *tmp;
   int had_err = 0;
-  unsigned long i;
+  GtUword i;
   gt_error_check(err);
   gt_assert(feature_index && gff3file);
   tmp = gt_array_new(sizeof (GtGenomeNode*));
@@ -242,6 +247,7 @@ int gt_feature_index_save(GtFeatureIndex *feature_index, GtError *err)
 {
   int ret;
   gt_assert(feature_index && feature_index->c_class);
+  gt_assert(feature_index->c_class->save_func);
   gt_rwlock_wrlock(feature_index->pvt->lock);
   ret = feature_index->c_class->save_func(feature_index, err);
   gt_rwlock_unlock(feature_index->pvt->lock);
@@ -273,6 +279,20 @@ int  gt_feature_index_get_range_for_seqid(GtFeatureIndex *feature_index,
   return ret;
 }
 
+int  gt_feature_index_get_orig_range_for_seqid(GtFeatureIndex *feature_index,
+                                               GtRange *range,
+                                               const char *seqid,
+                                               GtError *err)
+{
+  int ret;
+  gt_assert(feature_index && feature_index->c_class && range && seqid);
+  gt_rwlock_rdlock(feature_index->pvt->lock);
+  ret = feature_index->c_class->get_orig_range_for_seqid(feature_index, range,
+                                                         seqid, err);
+  gt_rwlock_unlock(feature_index->pvt->lock);
+  return ret;
+}
+
 int  gt_feature_index_has_seqid(const GtFeatureIndex *feature_index,
                                 bool *has_seqid,
                                 const char *seqid,
@@ -306,7 +326,7 @@ typedef struct {
   GtError *err;
   GtArray *nodes;
   GtMutex *mutex;
-  unsigned long next_node_idx,
+  GtUword next_node_idx,
                 error_count;
 } GtFeatureIndexTestShared;
 
@@ -340,7 +360,7 @@ static void* gt_feature_index_unit_test_query(void *data)
   GtFeatureIndexTestShared *shm = (GtFeatureIndexTestShared*) data;
   GtRange rng;
   GtError *err = shm->err;
-  unsigned long i;
+  GtUword i;
   int had_err = 0;
   GtArray *arr, *arr_ref;
 
@@ -429,26 +449,26 @@ int gt_feature_index_unit_test(GtFeatureIndex *fi, GtError *err)
                                           GT_FI_TEST_END);
 
   /* test seqid is not supposed to exist */
-  gt_ensure(had_err, gt_feature_index_has_seqid(sh.fi, &has_seqid,
+  gt_ensure(gt_feature_index_has_seqid(sh.fi, &has_seqid,
                                                  GT_FI_TEST_SEQID, err) == 0);
-  gt_ensure(had_err, !has_seqid);
+  gt_ensure(!has_seqid);
 
   /* add a sequence region directly and check if it has been added */
   rval = gt_feature_index_add_region_node(sh.fi, rn, err);
-  gt_ensure(had_err, rval == 0);
+  gt_ensure(rval == 0);
   gt_genome_node_delete((GtGenomeNode*) rn);
-  gt_ensure(had_err, gt_feature_index_has_seqid(sh.fi, &has_seqid,
+  gt_ensure(gt_feature_index_has_seqid(sh.fi, &has_seqid,
                                                 GT_FI_TEST_SEQID, err) == 0);
-  gt_ensure(had_err, has_seqid);
+  gt_ensure(has_seqid);
 
   gt_feature_index_get_range_for_seqid(sh.fi, &check_range, GT_FI_TEST_SEQID,
                                        err);
-  gt_ensure(had_err, check_range.start == GT_FI_TEST_START
+  gt_ensure(check_range.start == GT_FI_TEST_START
                     && check_range.end == GT_FI_TEST_END);
 
   /* set up nodes to store */
   for (i=0;i<GT_FI_TEST_FEATURES_PER_THREAD*gt_jobs;i++) {
-    unsigned long start, end;
+    GtUword start, end;
     GtFeatureNode *fn;
     start = random() % (GT_FI_TEST_END - GT_FI_TEST_FEATURE_WIDTH);
     end = start + random() % (GT_FI_TEST_FEATURE_WIDTH);
@@ -459,16 +479,16 @@ int gt_feature_index_unit_test(GtFeatureIndex *fi, GtError *err)
   /* test parallel addition */
   gt_multithread(gt_feature_index_unit_test_add, &sh, err);
   seqids = gt_feature_index_get_seqids(fi, err);
-  gt_ensure(had_err, seqids);
-  gt_ensure(had_err, gt_feature_index_has_seqid(fi, &has_seqid,GT_FI_TEST_SEQID,
+  gt_ensure(seqids);
+  gt_ensure(gt_feature_index_has_seqid(fi, &has_seqid,GT_FI_TEST_SEQID,
                                                 err) == 0);
-  gt_ensure(had_err, has_seqid);
-  gt_ensure(had_err, gt_str_array_size(seqids) == 1);
+  gt_ensure(has_seqid);
+  gt_ensure(gt_str_array_size(seqids) == 1);
 
   /* test parallel query */
   if (!had_err)
     gt_multithread(gt_feature_index_unit_test_query, &sh, err);
-  gt_ensure(had_err, sh.error_count == 0);
+  gt_ensure(sh.error_count == 0);
 
   gt_mutex_delete(sh.mutex);
   gt_error_delete(sh.err);
