@@ -211,14 +211,24 @@ static int construct_mRNAs(GT_UNUSED void *key, void *value, void *data,
 
   for (i = 1; !had_err && i < gt_array_size(gt_genome_node_array); i++) {
     GtRange range;
+    GtStrand strand;
     gn = *(GtGenomeNode**) gt_array_get(gt_genome_node_array, i);
     range = gt_genome_node_get_range(gn);
     mRNA_range = gt_range_join(&mRNA_range, &range);
-    /* XXX: an error check is necessary here, otherwise gt_strand_join() can
-       cause a failed assertion */
-    mRNA_strand = gt_strand_join(mRNA_strand,
-                          gt_feature_node_get_strand((GtFeatureNode*) gn));
-    if (gt_str_cmp(mRNA_seqid, gt_genome_node_get_seqid(gn))) {
+    strand = gt_feature_node_get_strand((GtFeatureNode*) gn);
+    if (strand != mRNA_strand) {
+      gt_error_set(err, "feature %s on line %u has strand %c, but the "
+                        "parent transcript has strand %c",
+                   (const char*) key,
+                   gt_genome_node_get_line_number(gn),
+                   GT_STRAND_CHARS[strand],
+                   GT_STRAND_CHARS[mRNA_strand]);
+      had_err = -1;
+      break;
+    } else {
+      mRNA_strand = gt_strand_join(mRNA_strand, strand);
+    }
+    if (!had_err && gt_str_cmp(mRNA_seqid, gt_genome_node_get_seqid(gn))) {
       gt_error_set(err, "The features on lines %u and %u refer to different "
                 "genomic sequences (``seqname''), although they have the same "
                 "gene IDs (``gene_id'') which must be globally unique",
@@ -232,6 +242,9 @@ static int construct_mRNAs(GT_UNUSED void *key, void *value, void *data,
   if (!had_err) {
     mRNA_node = gt_feature_node_new(mRNA_seqid, gt_ft_mRNA, mRNA_range.start,
                                     mRNA_range.end, mRNA_strand);
+    gt_feature_node_add_attribute(((GtFeatureNode*) mRNA_node), "ID", key);
+    gt_feature_node_add_attribute(((GtFeatureNode*) mRNA_node), "transcript_id",
+                                  key);
 
     if ((tname = gt_hashmap_get(cinfo->transcript_id_to_name_mapping,
                               (const char*) key)) && strlen(tname) > 0) {
@@ -297,16 +310,33 @@ static int construct_genes(GT_UNUSED void *key, void *value, void *data,
     gene_seqid = gt_genome_node_get_seqid(gn);
     for (i = 1; i < gt_array_size(mRNAs); i++) {
       GtRange range;
+      GtStrand strand;
       gn = *(GtGenomeNode**) gt_array_get(mRNAs, i);
       range = gt_genome_node_get_range(gn);
       gene_range = gt_range_join(&gene_range, &range);
-      gene_strand = gt_strand_join(gene_strand,
-                          gt_feature_node_get_strand((GtFeatureNode*) gn));
-      gt_assert(gt_str_cmp(gene_seqid, gt_genome_node_get_seqid(gn)) == 0);
+      strand = gt_feature_node_get_strand((GtFeatureNode*) gn);
+      if (strand != gene_strand) {
+        GT_UNUSED const char *transcript_name =
+                gt_feature_node_get_attribute((GtFeatureNode*) gn, GT_GFF_NAME);
+        gt_error_set(err, "transcript on strand %c encountered, but the "
+                          "parent gene %s has strand %c",
+                     GT_STRAND_CHARS[strand],
+                     (const char*) key,
+                     GT_STRAND_CHARS[gene_strand]);
+        had_err = -1;
+      } else {
+        gene_strand = gt_strand_join(gene_strand, strand);
+      }
+      gt_assert(had_err || gt_str_cmp(gene_seqid,
+                                      gt_genome_node_get_seqid(gn)) == 0);
     }
+  }
 
+  if (!had_err) {
     gene_node = gt_feature_node_new(gene_seqid, gt_ft_gene, gene_range.start,
                                     gene_range.end, gene_strand);
+    gt_feature_node_add_attribute((GtFeatureNode*) gene_node, "ID", key);
+    gt_feature_node_add_attribute((GtFeatureNode*) gene_node, "gene_id", key);
 
     if ((gname = gt_hashmap_get(cinfo->gene_id_to_name_mapping,
                               (const char*) key)) && strlen(gname) > 0) {
@@ -319,10 +349,16 @@ static int construct_genes(GT_UNUSED void *key, void *value, void *data,
       gn = *(GtGenomeNode**) gt_array_get(mRNAs, i);
       gt_feature_node_add_child((GtFeatureNode*) gene_node,
                                 (GtFeatureNode*) gn);
+      gt_feature_node_add_attribute((GtFeatureNode*) gn, "Parent", key);
+      gt_feature_node_add_attribute((GtFeatureNode*) gn, "gene_id", key);
     }
 
     /* store the gene */
     gt_queue_add(genome_nodes, gene_node);
+  } else {
+    for (i = 0; i < gt_array_size(mRNAs); i++) {
+      gt_genome_node_delete(*(GtGenomeNode**) gt_array_get(mRNAs, i));
+    }
   }
 
   /* free */
@@ -392,19 +428,19 @@ int gt_gtf_parser_parse(GtGTFParser *parser, GtQueue *genome_nodes,
   splitter = gt_splitter_new(),
   attribute_splitter = gt_splitter_new();
 
-#define HANDLE_ERROR                                                \
-        if (had_err) {                                              \
-          if (be_tolerant) {                                        \
+#define HANDLE_ERROR                                                   \
+        if (had_err) {                                                 \
+          if (be_tolerant) {                                           \
             fprintf(stderr, "skipping line: %s\n", gt_error_get(err)); \
             gt_error_unset(err);                                       \
             gt_str_reset(line_buffer);                                 \
-            had_err = 0;                                            \
-            continue;                                               \
-          }                                                         \
-          else {                                                    \
-            had_err = -1;                                           \
-            break;                                                  \
-          }                                                         \
+            had_err = 0;                                               \
+            continue;                                                  \
+          }                                                            \
+          else {                                                       \
+            had_err = -1;                                              \
+            break;                                                     \
+          }                                                            \
         }
 
   while (gt_str_read_next_line_generic(line_buffer, fpin) != EOF) {
@@ -429,6 +465,8 @@ int gt_gtf_parser_parse(GtGTFParser *parser, GtQueue *genome_nodes,
     }
     else {
       bool stop_codon = false;
+      char *tokendup, *attrkey;
+      GtStrArray *attrkeys, *attrvals;
 
       /* process tab delimited GTF line */
       gt_splitter_reset(splitter);
@@ -505,6 +543,8 @@ int gt_gtf_parser_parse(GtGTFParser *parser, GtQueue *genome_nodes,
       HANDLE_ERROR;
 
       /* parse the attributes */
+      attrkeys = gt_str_array_new();
+      attrvals = gt_str_array_new();
       gt_splitter_reset(attribute_splitter);
       gene_id = NULL;
       transcript_id = NULL;
@@ -515,6 +555,31 @@ int gt_gtf_parser_parse(GtGTFParser *parser, GtQueue *genome_nodes,
         /* skip leading blanks */
         while (*token == ' ')
           token++;
+
+        tokendup = gt_cstr_dup(token);
+        attrkey = strtok(tokendup, " ");
+        if (attrkey) {
+          char *attrval = strtok(NULL, " ");
+          if (attrval == NULL || strcmp(attrval, "") == 0 ||
+              strcmp(attrval, "\"\"") == 0)
+          {
+            gt_error_set(err, "missing value to attribute \"%s\" on line "
+                         GT_WU " in file \"%s\"", attrkey,line_number,filename);
+            had_err = -1;
+          }
+          HANDLE_ERROR;
+
+          if (*attrval == '"')
+            attrval++;
+          if (attrval[strlen(attrval)-1] == '"')
+            attrval[strlen(attrval)-1] = '\0';
+          gt_assert(attrkey && strlen(attrkey) > 0);
+          gt_assert(attrval && strlen(attrval) > 0);
+          gt_str_array_add_cstr(attrkeys, attrkey);
+          gt_str_array_add_cstr(attrvals, attrval);
+        }
+        gt_free(tokendup);
+
         /* look for the two mandatory attributes */
         if (strncmp(token, GENE_ID_ATTRIBUTE, strlen(GENE_ID_ATTRIBUTE)) == 0) {
           if (strlen(token) + 2 < strlen(GENE_ID_ATTRIBUTE)) {
@@ -525,6 +590,10 @@ int gt_gtf_parser_parse(GtGTFParser *parser, GtQueue *genome_nodes,
           }
           HANDLE_ERROR;
           gene_id = token + strlen(GENE_ID_ATTRIBUTE) + 1;
+          if (*gene_id == '"')
+            gene_id++;
+          if (gene_id[strlen(gene_id)-1] == '"')
+            gene_id[strlen(gene_id)-1] = '\0';
         }
         else if (strncmp(token, TRANSCRIPT_ID_ATTRIBUTE,
                          strlen(TRANSCRIPT_ID_ATTRIBUTE)) == 0) {
@@ -536,6 +605,10 @@ int gt_gtf_parser_parse(GtGTFParser *parser, GtQueue *genome_nodes,
           }
           HANDLE_ERROR;
           transcript_id = token + strlen(TRANSCRIPT_ID_ATTRIBUTE) + 1;
+          if (*transcript_id == '"')
+            transcript_id++;
+          if (transcript_id[strlen(transcript_id)-1] == '"')
+            transcript_id[strlen(transcript_id)-1] = '\0';
         }
         else if (strncmp(token, GENE_NAME_ATTRIBUTE,
                          strlen(GENE_NAME_ATTRIBUTE)) == 0) {
@@ -638,6 +711,29 @@ int gt_gtf_parser_parse(GtGTFParser *parser, GtQueue *genome_nodes,
         gt_feature_node_add_attribute((GtFeatureNode*) gn,
                                       GTF_PARSER_STOP_CODON_FLAG, "true");
       }
+      for (i = 0; i < gt_str_array_size(attrkeys); i++) {
+        GtFeatureNode *fn = (GtFeatureNode *)gn;
+        const char *key = gt_str_array_get(attrkeys, i);
+        const char *val = gt_str_array_get(attrvals, i);
+
+        /* Not a comprehensive solution to ensure correct encoding, just bare
+           minimum required to get Cufflinks output parsed */
+        if (strcmp(val, "=") == 0)
+          val = "%26";
+
+        if (gt_feature_node_get_attribute(fn, key) != NULL) {
+          const char *oldval = gt_feature_node_get_attribute(fn, key);
+          GtStr *newval = gt_str_new_cstr(oldval);
+          gt_str_append_char(newval, ',');
+          gt_str_append_cstr(newval, val);
+          gt_feature_node_set_attribute(fn, key, gt_str_get(newval));
+          gt_str_delete(newval);
+        }
+        else
+          gt_feature_node_add_attribute(fn, key, val);
+      }
+      gt_str_array_delete(attrkeys);
+      gt_str_array_delete(attrvals);
 
       /* set source */
       source_str = gt_hashmap_get(parser->source_to_str_mapping, source);
