@@ -19,6 +19,7 @@
 #include "lauxlib.h"
 #include "core/assert_api.h"
 #include "core/cstr_api.h"
+#include "core/fileutils.h"
 #include "core/gtdatapath.h"
 #include "core/ma.h"
 #include "extended/luahelper.h"
@@ -59,6 +60,20 @@ int gt_lua_set_modules_path(lua_State *L, GtError *err)
   return had_err;
 }
 
+void gt_lua_set_script_dir(lua_State *L, const char *scriptpath)
+{
+  GtStr *scriptdir = gt_str_new();
+  gt_file_dirname(scriptdir, scriptpath);
+  if (gt_str_length(scriptdir) == 0)
+    gt_str_append_cstr(scriptdir, ".");
+  lua_getglobal(L, "gt");
+  gt_assert(lua_istable(L, -1));
+  lua_pushstring(L, gt_str_get(scriptdir));
+  lua_setfield(L, -2, "script_dir");
+  lua_pop(L, 1);
+  gt_str_delete(scriptdir);
+}
+
 void gt_lua_set_arg(lua_State *L, const char *argv_0, const char **argv)
 {
   lua_Integer n = 0;
@@ -133,3 +148,20 @@ int gt_lua_error(lua_State *L, GtError *err)
   lua_concat(L, 2);
   return lua_error(L);
 }
+
+void* gt_lua_try_checkudata(lua_State *L, int ud, const char *tname)
+{
+  void *p;
+  gt_assert(L && tname);
+  p = lua_touserdata(L, ud);
+  if (p != NULL) {  /* value is a userdata? */
+    if (lua_getmetatable(L, ud)) {  /* does it have a metatable? */
+      lua_getfield(L, LUA_REGISTRYINDEX, tname);  /* get correct metatable */
+      if (lua_rawequal(L, -1, -2)) {  /* does it have the correct mt? */
+        lua_pop(L, 2);  /* remove both metatables */
+        return p;
+      }
+    }
+  }
+  return NULL;  /* to avoid warnings */
+}
