@@ -25,6 +25,7 @@
 #include "core/ma.h"
 #include "core/xansi_api.h"
 #include "extended/multieoplist.h"
+#include "core/log_api.h"
 
 typedef uint8_t Eop;
 
@@ -50,8 +51,8 @@ GtMultieoplist *gt_multieoplist_new_with_size(GtUword size)
   multieops = gt_malloc(sizeof (GtMultieoplist));
   multieops->refcount = 0;
   GT_INITARRAY(&multieops->meoplist, Eop);
-  multieops->meoplist.spaceEop = gt_calloc((size_t) size,
-                              sizeof (*(multieops->meoplist.spaceEop)));
+  multieops->meoplist.spaceEop =
+    gt_calloc((size_t) size, sizeof (*(multieops->meoplist.spaceEop)));
   multieops->meoplist.allocatedEop = size;
   return multieops;
 }
@@ -289,6 +290,11 @@ void gt_multieoplist_show(GtMultieoplist *multieops, FILE *fp)
           num = multieops->meoplist.nextfreeEop;
   Eop *space, *last, *next;
 
+  if (num == 0)
+  {
+    gt_xfputs("[]\n", fp);
+    return;
+  }
   gt_assert(multieops != NULL);
   space = multieops->meoplist.spaceEop;
 
@@ -323,8 +329,9 @@ void gt_multieoplist_show(GtMultieoplist *multieops, FILE *fp)
       stepssum = (GtUword) (*last & GT_MEOPS_STEPS_MASK);
       next = last - 1;
     }
+    gt_assert(next + 1 == last);
   }
-  gt_assert(last == space);
+  gt_assert(num == 0 || last == space);
   switch (*last >> GT_MEOPS_STEPS_BITS) {
     case GT_MEOPS_MATCH:
       gt_xfputc('M', fp);
@@ -402,6 +409,28 @@ GtMultieoplist *gt_multieoplist_io(GtMultieoplist *multieops, FILE *fp,
   return multieops;
 }
 
+int gt_multieoplist_unit_test_2(GtError *err)
+{
+  /* char *u = "attttgatatcgtctctctatgctgtcac", */
+       /* *v = "atttngatatcgtctctctatgctgtcac"; */
+  GtMultieoplist *meop = gt_multieoplist_new();
+  unsigned int i;
+  int had_err = 0;
+
+  for (i = 0; i < 4; ++i) {
+    gt_multieoplist_add_match(meop);
+  }
+  gt_multieoplist_add_mismatch(meop);
+  for (i = 0; i < 24; ++i) {
+    gt_multieoplist_add_match(meop);
+  }
+  gt_ensure(gt_multieoplist_get_length(meop) == 29);
+  gt_log_log("length: " GT_WU, gt_multieoplist_get_length(meop));
+
+  gt_multieoplist_delete(meop);
+  return had_err;
+}
+
 int gt_multieoplist_unit_test(GtError *err)
 {
   int had_err = 0;
@@ -474,5 +503,6 @@ int gt_multieoplist_unit_test(GtError *err)
   gt_multieoplist_delete(list);
   gt_multieoplist_delete(list2);
 
+  had_err = gt_multieoplist_unit_test_2(err);
   return had_err;
 }
