@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2010      Sascha Kastens <sascha.kastens@studium.uni-hamburg.de>
+  Copyright (c) 2010      Sascha Kastens <mail@skastens.de>
   Copyright (c)      2011 Sascha Steinbiss <steinbiss@zbh.uni-hamburg.de>
   Copyright (c) 2010-2011 Center for Bioinformatics, University of Hamburg
 
@@ -51,7 +51,7 @@ static int gt_orf_finder_stream_next(GtNodeStream *gs, GtGenomeNode **gn,
 
   had_err = gt_node_stream_next(ls->in_stream, gn, err);
   if (!had_err && *gn) {
-    (void) gt_genome_node_accept(*gn, (GtNodeVisitor*) ls->lv, err);
+    had_err = gt_genome_node_accept(*gn, (GtNodeVisitor*) ls->lv, err);
   }
   if (had_err) {
     gt_genome_node_delete(*gn);
@@ -81,7 +81,7 @@ const GtNodeStreamClass* gt_orf_finder_stream_class(void)
 }
 
 GtNodeStream* gt_orf_finder_stream_new(GtNodeStream *in_stream,
-                                       GtEncseq *encseq,
+                                       GtRegionMapping *rmap,
                                        GtHashmap *types,
                                        unsigned int min,
                                        unsigned int max,
@@ -93,7 +93,7 @@ GtNodeStream* gt_orf_finder_stream_new(GtNodeStream *in_stream,
   gs = gt_node_stream_create(gt_orf_finder_stream_class(), false);
   ls = gt_orf_finder_stream_cast(gs);
   ls->in_stream = gt_node_stream_ref(in_stream);
-  ls->lv = (GtORFFinderVisitor*) gt_orf_finder_visitor_new(encseq,types,
+  ls->lv = (GtORFFinderVisitor*) gt_orf_finder_visitor_new(rmap,types,
                                                            min, max, all, err);
   return gs;
 }
