@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2006-2012 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2006-2012 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2006-2008 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -94,11 +94,11 @@ GtNodeStream* gt_select_stream_new(GtNodeStream *in_stream, GtStr *seqid,
                                    GtStr *source, const GtRange *contain_range,
                                    const GtRange *overlap_range,
                                    GtStrand strand, GtStrand targetstrand,
-                                   bool has_CDS, unsigned long max_gene_length,
-                                   unsigned long max_gene_num,
+                                   bool has_CDS, GtUword max_gene_length,
+                                   GtUword max_gene_num,
                                    double min_gene_score, double max_gene_score,
                                    double min_average_splice_site_prob,
-                                   unsigned long feature_num,
+                                   GtUword feature_num,
                                    GtStrArray *select_files,
                                    GtStr *select_logic, GtError *err)
 {
