@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2003-2009 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2003-2009 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2003-2008 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -21,7 +21,9 @@
 #include "core/error.h"
 
 /* the gthbssmbuild tool */
-int gt_gthbssmbuild(int argc, const char **argv,
-                    GtShowVersionFunc gth_version_func, GtError*);
+int gt_gthbssmbuild(int argc, const char **argv, GtError*);
+
+int gt_gthbssmbuild_with_version_func(int argc, const char **argv,
+                                      GtShowVersionFunc version_func, GtError*);
 
 #endif
