@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2005-2011 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2005-2011 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2005-2008 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -65,7 +65,7 @@ static GtOPrval gthfilestat_parse_options(int *parsed_args,
   o = gt_option_new_verbose(&verbose);
   gt_option_parser_add_option(op, o);
 
-  gt_option_parser_set_mail_address(op, "<gremme@zbh.uni-hamburg.de>");
+  gt_option_parser_set_mail_address(op, "<gordon@gremme.org>");
   oprval = gt_option_parser_parse(op, parsed_args, argc, argv,
                                   plugins->gth_version_func, err);
 
