@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2003-2007, 2012 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2003-2007, 2012 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2003-2007       Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -21,12 +21,15 @@
 /* file suffixes for different indices */
 #define DNASUFFIX               "dna"
 #define POLYASUFFIX             "polya"
-#define MAXSUFFIXLEN            11
+#define MAXSUFFIXLEN            14
 
 /* the name of the environment variable containing the path for gth data */
-#define GTHDATAENVNAME                  "GTHDATADIR"
+#define GTHDATAENVNAME          "GTHDATADIR"
+
+/* the name of the gth data file path relative to binary */
+#define GTHDATADIRNAME          "gthdata"
 
 /* the name of the environment variable used to disable file locking */
-#define GTHNOFLOCKENVNAME               "GTHNOFLOCK"
+#define GTHNOFLOCKENVNAME       "GTHNOFLOCK"
 
 #endif
