@@ -612,9 +612,9 @@ static void show_parse_file_status(GthShowVerbose showverbose,
 {
   GtStr *buf = gt_str_new();
   gt_str_append_cstr(buf, "process file ");
-  gt_str_append_ulong(buf, filenum + 1);
+  gt_str_append_uword(buf, filenum + 1);
   gt_str_append_char(buf, GT_PATH_SEPARATOR);
-  gt_str_append_ulong(buf, numoffiles);
+  gt_str_append_uword(buf, numoffiles);
   gt_str_append_cstr(buf, ": ");
   gt_str_append_cstr(buf, filename);
   showverbose(gt_str_get(buf));
