@@ -1,6 +1,6 @@
 /*
-  Copyright (c) 2003-2012 Gordon Gremme <gordon@gremme.org>
-  Copyright (c) 2003-2008 Center for Bioinformatics, University of Hamburg
+  Copyright (c) 2003-2012, 2014 Gordon Gremme <gordon@gremme.org>
+  Copyright (c) 2003-2008       Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
   purpose with or without fee is hereby granted, provided that the above
@@ -103,7 +103,7 @@ GtOPrval gth_parse_options(GthCallInfo *call_info, GthInput *input,
         *termcutoffsmode, *duplicatecheck;
   bool forward = false, reverse = false, verbose, mincutoffs = false,
        nou12intronmodel, exondistri, introndistri, refseqcovdistri = false,
-       matchnumdistri = false;
+       cdnaforwardonly = false, matchnumdistri = false;
   GtOptionParser *op;
   GtOutputFileInfo *ofi;
   GtOption *optgenomic = NULL,              /* mandatory input */
@@ -115,6 +115,7 @@ GtOPrval gth_parse_options(GthCallInfo *call_info, GthInput *input,
          *opttranslationtable = NULL,     /* translationtable */
          *optforward = NULL,              /* strand direction */
          *optreverse = NULL,              /* strand direction */
+         *optcdnaforward = NULL,          /* strand direction */
          *optfrompos = NULL,              /* genomic sequence positions */
          *opttopos = NULL,                /* genomic sequence positions */
          *optwidth = NULL,                /* genomic sequence positions */
@@ -339,6 +340,14 @@ GtOPrval gth_parse_options(GthCallInfo *call_info, GthInput *input,
     gt_option_parser_add_option(op, optreverse);
   }
 
+  /* -cdnaforward */
+  if (!gthconsensus_parsing) {
+    optcdnaforward = gt_option_new_bool("cdnaforward", "align only forward "
+                                        "strand of cDNAs",
+                                        &call_info->cdnaforward, false);
+    gt_option_parser_add_option(op, optcdnaforward);
+  }
+
   /* -frompos */
   if (!gthconsensus_parsing) {
     optfrompos = gt_option_new_uword_min(FROMPOS_OPT_CSTR, "analyze genomic "
@@ -1199,11 +1208,11 @@ GtOPrval gth_parse_options(GthCallInfo *call_info, GthInput *input,
   gt_option_is_development_option(optdisableclustersas);
   gt_option_parser_add_option(op, optdisableclustersas);
 
-  /* -cdnaforwardonly */
+  /* -cdnaforwardonly (keep option for backward compatibility) */
   if (!gthconsensus_parsing) {
-    optcdnaforwardonly = gt_option_new_bool("cdnaforwardonly", "consider only "
-                                         "forward strand of cDNAs",
-                                         &call_info->cdnaforwardonly, false);
+    optcdnaforwardonly = gt_option_new_bool("cdnaforwardonly", "align only "
+                                            "forward strand of cDNAs",
+                                            &cdnaforwardonly, false);
     gt_option_is_development_option(optcdnaforwardonly);
     gt_option_parser_add_option(op, optcdnaforwardonly);
   }
@@ -1495,7 +1504,7 @@ GtOPrval gth_parse_options(GthCallInfo *call_info, GthInput *input,
   if (oprval == GT_OPTION_PARSER_OK && optproteinsmap &&
       !gt_option_is_set(optproteinsmap)) {
     if (gt_str_length(gth_input_proteinsmap(input)) > MAXSUFFIXLEN) {
-      gt_error_set(err, "\%s argument \"%s\" is too long (>MAXSUFFIXLEN=%u)",
+      gt_error_set(err, "%s argument \"%s\" is too long (>MAXSUFFIXLEN=%u)",
                 PROTEINSMAP_OPT_CSTR,
                 gt_str_get(gth_input_proteinsmap(input)), MAXSUFFIXLEN);
       oprval = GT_OPTION_PARSER_ERROR;
@@ -1561,6 +1570,10 @@ GtOPrval gth_parse_options(GthCallInfo *call_info, GthInput *input,
     }
   }
 
+  /* backward compatibility */
+  if (cdnaforwardonly && !gt_option_is_set(optcdnaforward))
+    call_info->cdnaforward = true;
+
   /* assertions */
 #ifndef NDEBUG
   if (oprval == GT_OPTION_PARSER_OK && !gthconsensus_parsing) {
