@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2008 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2008 Gordon Gremme <gordon@gremme.org>
   Copyright (c) 2008 Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
@@ -19,6 +19,7 @@
 #define REGION_MAPPING_LUA_H
 
 #include "lua.h"
+#include "extended/region_mapping_api.h"
 
 /* exports the RegionMapping class to Lua:
 
@@ -28,6 +29,9 @@
 */
 int gt_lua_open_region_mapping(lua_State*);
 
+/* Push a <GtRegionMapping*> to Lua, takes ownership! */
+void gt_lua_region_mapping_push(lua_State *L, GtRegionMapping *rm);
+
 #define REGION_MAPPING_METATABLE  "GenomeTools.region_mapping"
 #define check_region_mapping(L, POS) \
         (GtRegionMapping**) luaL_checkudata(L, POS, REGION_MAPPING_METATABLE)
