@@ -11,6 +11,7 @@
 #include "core/divmodmul.h"
 #include "core/intbits.h"
 #include "core/encseq.h"
+#include "match/extend-offset.h"
 #include "core/ma_api.h"
 #include "core/types_api.h"
 #include "ft-front-prune.h"
@@ -19,13 +20,20 @@
 #include "ft-polish.h"
 #include "ft-front-generation.h"
 
-#define UPDATE_MATCH_HISTORY(MC,MH)\
-        if ((MH) & mask)\
+#define GT_UPDATE_MATCH_HISTORY(FRONTVAL)\
+        if ((FRONTVAL)->matchhistory_size == max_history)\
         {\
-          gt_assert((MC) > 0);\
-          (MC)--;\
+          if ((FRONTVAL)->matchhistory_bits & leftmostbit)\
+          {\
+            gt_assert((FRONTVAL)->matchhistory_count > 0);\
+            (FRONTVAL)->matchhistory_count--;\
+          }\
+        } else\
+        {\
+          gt_assert((FRONTVAL)->matchhistory_size < max_history);\
+          (FRONTVAL)->matchhistory_size++;\
         }\
-        (MH) <<= 1
+        (FRONTVAL)->matchhistory_bits <<= 1
 
 typedef unsigned int Rowvaluetype;
 typedef uint8_t Matchcounttype;
@@ -33,10 +41,11 @@ typedef uint8_t Backreferencetype;
 
 typedef struct
 {
-  uint64_t matchhistory;
+  uint64_t matchhistory_bits;
   Rowvaluetype row,
                localmatch_count;
-  Matchcounttype matchhistory_count;
+  Matchcounttype matchhistory_count,
+                 matchhistory_size;
   Backreferencetype backreference;
 } Frontvalue;
 
@@ -45,27 +54,33 @@ typedef struct
 {
   const GtTwobitencoding *twobitencoding;
   const GtEncseq *encseq;
-  bool forward;
+  const GtUchar *bytesequenceptr;
   GtEncseqReader *encseqreader;
   GtUchar *cache_ptr;
   GtAllocatedMemory *sequence_cache;
   GtUword substringlength,
-          min_access_pos,
-          cache_num_positions,
-          cache_offset,
-          startpos;
+          totallength,
+          min_access_pos, /* no position accessed will be smaller than this */
+          cache_num_positions; /* number of positions in cache */
+  GtUword offset,
+          seqstartpos;
+  bool read_seq_left2right,
+       dir_is_complement;
 } Sequenceobject;
 
-static void sequenceobject_init(Sequenceobject *seq,
-                                GtExtendCharAccess extend_char_access_mode,
-                                const GtEncseq *encseq,
-                                GtReadmode readmode,
-                                GtUword startpos,
-                                GtUword len,
-                                GtEncseqReader *encseq_r,
-                                GtAllocatedMemory *sequence_cache,
-                                GtUword totallength
-                                )
+static void ft_sequenceobject_init(Sequenceobject *seq,
+                                   GtExtendCharAccess extend_char_access_mode,
+                                   const GtEncseq *encseq,
+                                   bool rightextension,
+                                   GtReadmode readmode,
+                                   GtUword seqstartpos,
+                                   GtUword startpos,
+                                   GtUword len,
+                                   GtEncseqReader *encseq_r,
+                                   GtAllocatedMemory *sequence_cache,
+                                   const GtUchar *bytesequence,
+                                   GtUword totallength
+                                   )
 {
   gt_assert(seq != NULL);
   seq->encseq = NULL;
@@ -73,46 +88,60 @@ static void sequenceobject_init(Sequenceobject *seq,
   seq->twobitencoding = NULL;
   seq->cache_ptr = NULL;
   seq->sequence_cache = NULL;
-  if (extend_char_access_mode == GT_EXTEND_CHAR_ACCESS_ANY &&
+  seq->bytesequenceptr = NULL;
+  seq->seqstartpos = seqstartpos;
+  gt_assert(seqstartpos <= startpos);
+  seq->offset = GT_EXTEND_OFFSET(rightextension,
+                                 readmode,
+                                 totallength,
+                                 seqstartpos,
+                                 startpos,
+                                 len);
+  seq->read_seq_left2right = GT_EXTEND_READ_SEQ_LEFT2RIGHT(rightextension,
+                                                           readmode);
+  if (encseq != NULL && extend_char_access_mode == GT_EXTEND_CHAR_ACCESS_ANY &&
       gt_encseq_has_twobitencoding(encseq) && gt_encseq_wildcards(encseq) == 0)
   {
     seq->twobitencoding = gt_encseq_twobitencoding_export(encseq);
   }
-  if (seq->twobitencoding == NULL &&
+  if (encseq != NULL && seq->twobitencoding == NULL &&
       (extend_char_access_mode == GT_EXTEND_CHAR_ACCESS_ANY ||
        extend_char_access_mode == GT_EXTEND_CHAR_ACCESS_ENCSEQ_READER))
   {
-    gt_encseq_reader_reinit_with_readmode(encseq_r, encseq, readmode, startpos);
+    GtUword full_totallength = gt_encseq_total_length(encseq);
+    gt_encseq_reader_reinit_with_readmode(encseq_r, encseq,
+                                          seq->read_seq_left2right
+                                            ? GT_READMODE_FORWARD
+                                            : GT_READMODE_REVERSE,
+                                          seq->read_seq_left2right
+                                            ? seq->offset
+                                            : GT_REVERSEPOS(full_totallength,
+                                                            seq->offset));
     seq->encseqreader = encseq_r;
-    gt_assert(seq->encseqreader != NULL);
+    gt_assert(seq->encseqreader != NULL && sequence_cache != NULL);
     seq->sequence_cache = sequence_cache;
-    gt_assert(sequence_cache != NULL);
-    seq->cache_ptr = sequence_cache->space;
-    seq->min_access_pos = GT_UWORD_MAX;
+    seq->cache_ptr = (GtUchar *) sequence_cache->space;
+    seq->min_access_pos = GT_UWORD_MAX; /* undefined */
     seq->cache_num_positions = 0;
-    seq->cache_offset = 0;
   }
-  if (seq->twobitencoding == NULL && seq->encseqreader == NULL &&
+  if (encseq != NULL && seq->twobitencoding == NULL &&
+      seq->encseqreader == NULL &&
       (extend_char_access_mode == GT_EXTEND_CHAR_ACCESS_ANY ||
        extend_char_access_mode == GT_EXTEND_CHAR_ACCESS_ENCSEQ))
   {
     seq->encseq = encseq;
   }
-  seq->substringlength = len;
-  if (readmode == GT_READMODE_FORWARD)
+  if (extend_char_access_mode == GT_EXTEND_CHAR_ACCESS_DIRECT)
   {
-    seq->startpos = startpos;
-    seq->forward = true;
-  } else
-  {
-    gt_assert(readmode == GT_READMODE_REVERSE);
-    gt_assert(gt_encseq_total_length(encseq) == totallength);
-    gt_assert(startpos + 1 <= totallength);
-    seq->startpos = totallength - 1 - startpos;
-    seq->forward = false;
+    gt_assert(seq->twobitencoding == NULL && seq->encseqreader == NULL &&
+              seq->encseq == NULL);
+    seq->bytesequenceptr = bytesequence;
   }
+  seq->substringlength = len;
+  seq->totallength = totallength;
+  seq->dir_is_complement = GT_ISDIRCOMPLEMENT(readmode) ? true : false;
   gt_assert(seq->twobitencoding != NULL || seq->encseqreader != NULL ||
-            seq->encseq != NULL);
+            seq->encseq != NULL || seq->bytesequenceptr != NULL);
 }
 
 static GtUchar gt_twobitencoding_char_at_pos(
@@ -123,48 +152,38 @@ static GtUchar gt_twobitencoding_char_at_pos(
           GT_MULT2(GT_UNITSIN2BITENC - 1 - GT_MODBYUNITSIN2BITENC(pos))) & 3;
 }
 
-static GtUchar sequenceobject_get_char(Sequenceobject *seq,GtUword pos)
+static GtUchar ft_sequenceobject_get_char(Sequenceobject *seq,GtUword idx)
 {
+  GtUchar cc;
+  GtUword accesspos;
+
   if (seq->twobitencoding != NULL)
   {
-    return gt_twobitencoding_char_at_pos(seq->twobitencoding,
-                                         seq->forward ? seq->startpos + pos
-                                                      : seq->startpos - pos);
+    gt_assert (seq->read_seq_left2right || seq->offset >= idx);
+    accesspos = seq->read_seq_left2right ? seq->offset + idx
+                                         : seq->offset - idx;
+    gt_assert(accesspos < seq->seqstartpos + seq->totallength);
+    cc = gt_twobitencoding_char_at_pos(seq->twobitencoding, accesspos);
+    return seq->dir_is_complement ? GT_COMPLEMENTBASE(cc) : cc;
   }
   if (seq->encseqreader != NULL)
   {
-    const GtUword addamount = 256UL;
-
-    if (seq->min_access_pos != GT_UWORD_MAX &&
-        seq->min_access_pos >= seq->cache_offset + addamount)
-    {
-      GtUword idx, end = MIN(seq->cache_num_positions,seq->substringlength);
-      GtUchar *cs = ((GtUchar *) seq->sequence_cache->space)
-                    - seq->min_access_pos;
-
-      for (idx = seq->min_access_pos; idx < end; idx++)
-      {
-        cs[idx] = seq->cache_ptr[idx];
-      }
-      seq->cache_offset = seq->min_access_pos;
-      seq->cache_ptr = ((GtUchar *) seq->sequence_cache->space)
-                       - seq->cache_offset;
-    }
-    if (pos >= seq->cache_num_positions)
+    gt_assert(idx < seq->substringlength);
+    if (idx >= seq->cache_num_positions)
     {
       GtUword idx, tostore;
+      const GtUword addamount = 256UL;
 
-      tostore = MIN(seq->cache_num_positions + addamount,seq->substringlength);
-      if (tostore > seq->cache_offset + seq->sequence_cache->allocated)
+      tostore = MIN(seq->cache_num_positions + addamount,
+                    seq->substringlength);
+      if (tostore > seq->sequence_cache->allocated)
       {
         seq->sequence_cache->allocated += addamount;
         seq->sequence_cache->space
           = gt_realloc(seq->sequence_cache->space,
                        sizeof (GtUchar) * seq->sequence_cache->allocated);
-        seq->cache_ptr = ((GtUchar *) seq->sequence_cache->space)
-                         - seq->cache_offset;
+        seq->cache_ptr = (GtUchar *) seq->sequence_cache->space;
       }
-      gt_assert(pos >= seq->cache_offset);
       for (idx = seq->cache_num_positions; idx < tostore; idx++)
       {
         seq->cache_ptr[idx]
@@ -172,18 +191,74 @@ static GtUchar sequenceobject_get_char(Sequenceobject *seq,GtUword pos)
       }
       seq->cache_num_positions = tostore;
     }
-    gt_assert(pos < seq->cache_offset + seq->sequence_cache->allocated);
-    gt_assert(seq->cache_ptr != NULL);
-    return seq->cache_ptr[pos];
+    gt_assert(seq->cache_ptr != NULL && idx < seq->cache_num_positions);
+    cc = seq->cache_ptr[idx];
+  } else
+  {
+    accesspos = seq->read_seq_left2right ? seq->offset + idx
+                                         : seq->offset - idx;
+    if (seq->encseq != NULL)
+    {
+      cc = gt_encseq_get_encoded_char(seq->encseq,accesspos,
+                                      GT_READMODE_FORWARD);
+    } else
+    {
+      gt_assert(seq->bytesequenceptr != NULL);
+      cc = seq->bytesequenceptr[accesspos];
+    }
   }
-  gt_assert(seq->encseq != NULL);
-  gt_assert(seq->forward || seq->startpos >= pos);
-  return gt_encseq_get_encoded_char(seq->encseq,
-                                    seq->forward ? seq->startpos + pos
-                                                 : seq->startpos - pos,
-                                    GT_READMODE_FORWARD);
+  if (seq->dir_is_complement && !ISSPECIAL(cc))
+  {
+    return GT_COMPLEMENTBASE(cc);
+  }
+  return cc;
 }
 
+#undef SKDEBUG
+#ifdef SKDEBUG
+static char *gt_ft_sequencebject_get(Sequenceobject *seq)
+{
+  GtUword idx;
+  char *buffer;
+  char *map = "acgt";
+
+  gt_assert(seq != NULL);
+  buffer = gt_malloc(sizeof *buffer * (seq->substringlength+1));
+  for (idx = 0; idx < seq->substringlength; idx++)
+  {
+    GtUchar cc = ft_sequenceobject_get_char(seq,idx);
+
+    if (cc == WILDCARD)
+    {
+      buffer[idx] = '#';
+    } else
+    {
+      if (cc == SEPARATOR)
+      {
+        buffer[idx] = '$';
+      } else
+      {
+        gt_assert(cc < 4);
+        buffer[idx] = map[cc];
+      }
+    }
+  }
+  buffer[seq->substringlength] = '\0';
+  return buffer;
+}
+
+static void gt_greedy_show_context(bool rightextension,
+                                   Sequenceobject *useq,Sequenceobject *vseq)
+{
+  char *uptr = gt_ft_sequencebject_get(useq);
+  char *vptr = gt_ft_sequencebject_get(vseq);
+  printf(">%sextension:\n>%s\n>%s\n",rightextension ? "right" : "left",
+         uptr,vptr);
+  gt_free(uptr);
+  gt_free(vptr);
+}
+#endif
+
 #else
 typedef struct
 {
@@ -191,80 +266,89 @@ typedef struct
   GtUword substringlength;
 } Sequenceobject;
 
-static void sequenceobject_init(Sequenceobject *seq,
-                                const GtUchar *ptr,
-                                GtUword startpos,
-                                GtUword len)
+static void ft_sequenceobject_init(Sequenceobject *seq,
+                                   const GtUchar *ptr,
+                                   GtUword seqstartpos,
+                                   GtUword startpos,
+                                   GtUword len)
 {
   gt_assert(seq != NULL);
-  seq->sequence_ptr = ptr + startpos;
+  seq->sequence_ptr = ptr + seqstartpos + startpos;
   seq->substringlength = len;
 }
 #endif
 
 #define FRONT_DIAGONAL(FRONTPTR) (GtWord) ((FRONTPTR) - midfront)
 
-static bool sequenceobject_symbol_match(Sequenceobject *useq,
-                                        GtUword upos,
-                                        Sequenceobject *vseq,
-                                        GtUword vpos)
+static bool ft_sequenceobject_symbol_match(Sequenceobject *useq,
+                                           GtUword upos,
+                                           Sequenceobject *vseq,
+                                           GtUword vpos)
 {
 #ifndef OUTSIDE_OF_GT
-  GtUchar cu = sequenceobject_get_char(useq,upos);
+  GtUchar cu = ft_sequenceobject_get_char(useq,upos);
   if (ISSPECIAL(cu))
   {
     return false;
   }
-  return cu == sequenceobject_get_char(vseq,vpos) ? true : false;
+  return cu == ft_sequenceobject_get_char(vseq,vpos) ? true : false;
 #else
   GtUchar cu = useq->sequence_ptr[upos];
   return cu == vseq->sequence_ptr[vpos] ? true : false;
 #endif
 }
 
-static void inline add_matches(Frontvalue *midfront,
-                               Frontvalue *fv,
-                               uint64_t mask,
-                               Sequenceobject *useq,
-                               Sequenceobject *vseq)
+static void inline front_prune_add_matches(Frontvalue *midfront,
+                                           Frontvalue *fv,
+                                           uint64_t leftmostbit,
+                                           GtUword max_history,
+                                           Sequenceobject *useq,
+                                           Sequenceobject *vseq)
 {
   GtUword upos, vpos;
 
-  fv->localmatch_count = 0;
   for (upos = fv->row, vpos = fv->row + FRONT_DIAGONAL(fv);
        upos < useq->substringlength && vpos < vseq->substringlength &&
-       sequenceobject_symbol_match(useq,upos,vseq,vpos);
+       ft_sequenceobject_symbol_match(useq,upos,vseq,vpos);
        upos++, vpos++)
   {
-    fv->localmatch_count++;
-    if (!(fv->matchhistory & mask))
+    if (fv->matchhistory_size == max_history)
     {
-      gt_assert(fv->matchhistory_count < INT8_MAX);
+      if (!(fv->matchhistory_bits & leftmostbit))
+      {
+        gt_assert(fv->matchhistory_count < INT8_MAX);
+        fv->matchhistory_count++;
+      }
+    } else
+    {
+      gt_assert(fv->matchhistory_size < max_history);
+      fv->matchhistory_size++;
       fv->matchhistory_count++;
     }
-    fv->matchhistory = (fv->matchhistory << 1) | (uint64_t) 1;
+    fv->matchhistory_bits = (fv->matchhistory_bits << 1) | (uint64_t) 1;
   }
-  fv->row += fv->localmatch_count;
+  fv->localmatch_count = upos - fv->row;
+  fv->row = upos;
 }
 
 static GtUword front_next_inplace(Frontvalue *midfront,
                                   Frontvalue *lowfront,
                                   Frontvalue *highfront,
-                                  GtUword history,
+                                  GtUword max_history,
                                   Sequenceobject *useq,
                                   Sequenceobject *vseq)
 {
   GtUword alignedlen, maxalignedlen;
-  const uint64_t mask = ((uint64_t) 1) << (history-1);
+  const uint64_t leftmostbit = ((uint64_t) 1) << (max_history-1);
   Frontvalue bestfront, insertion_value, replacement_value, *frontptr;
 
   insertion_value = *lowfront; /* from previous diag -(d-1) => -d => DELETION */
   bestfront = insertion_value;
   bestfront.row++;
-  UPDATE_MATCH_HISTORY(bestfront.matchhistory_count,bestfront.matchhistory);
+  GT_UPDATE_MATCH_HISTORY(&bestfront);
   *lowfront = bestfront;
   lowfront->backreference = FT_EOP_DELETION;
-  add_matches(midfront,lowfront,mask,useq,vseq);
+  front_prune_add_matches(midfront,lowfront,leftmostbit,max_history,useq,vseq);
   maxalignedlen = GT_MULT2(lowfront->row) + FRONT_DIAGONAL(lowfront);
 
   replacement_value = *(lowfront+1);
@@ -273,7 +357,7 @@ static GtUword front_next_inplace(Frontvalue *midfront,
     bestfront = replacement_value;
     bestfront.backreference = FT_EOP_DELETION;
     bestfront.row++;
-    UPDATE_MATCH_HISTORY(bestfront.matchhistory_count,bestfront.matchhistory);
+    GT_UPDATE_MATCH_HISTORY(&bestfront);
   } else
   {
     bestfront.backreference = FT_EOP_REPLACEMENT;
@@ -283,7 +367,8 @@ static GtUword front_next_inplace(Frontvalue *midfront,
     }
   }
   *(lowfront+1) = bestfront;
-  add_matches(midfront,lowfront + 1,mask,useq,vseq);
+  front_prune_add_matches(midfront,lowfront + 1,leftmostbit,max_history,
+                          useq,vseq);
   alignedlen = GT_MULT2((lowfront+1)->row) + FRONT_DIAGONAL(lowfront + 1);
   if (maxalignedlen < alignedlen)
   {
@@ -323,14 +408,15 @@ static GtUword front_next_inplace(Frontvalue *midfront,
         }
       }
     }
-    UPDATE_MATCH_HISTORY(bestfront.matchhistory_count,bestfront.matchhistory);
+    GT_UPDATE_MATCH_HISTORY(&bestfront);
     if (frontptr < highfront)
     {
       insertion_value = replacement_value;
       replacement_value = *frontptr;
     }
     *frontptr = bestfront;
-    add_matches(midfront,frontptr,mask,useq,vseq);
+    front_prune_add_matches(midfront,frontptr,leftmostbit,max_history,
+                            useq,vseq);
     alignedlen = GT_MULT2(frontptr->row) + FRONT_DIAGONAL(frontptr);
     if (maxalignedlen < alignedlen)
     {
@@ -342,25 +428,25 @@ static GtUword front_next_inplace(Frontvalue *midfront,
 
 static GtUword front_second_inplace(Frontvalue *midfront,
                                     Frontvalue *lowfront,
-                                    GtUword history,
+                                    GtUword max_history,
                                     Sequenceobject *useq,
                                     Sequenceobject *vseq)
 {
   GtUword alignedlen, maxalignedlen;
-  const uint64_t mask = ((uint64_t) 1) << (history-1);
+  const uint64_t leftmostbit = ((uint64_t) 1) << (max_history-1);
 
   *(lowfront+1) = *(lowfront+2) = *lowfront;
   lowfront->row++;
   lowfront->backreference = FT_EOP_DELETION;
-  UPDATE_MATCH_HISTORY(lowfront->matchhistory_count,lowfront->matchhistory);
-  add_matches(midfront,lowfront,mask,useq,vseq);
+  GT_UPDATE_MATCH_HISTORY(lowfront);
+  front_prune_add_matches(midfront,lowfront,leftmostbit,max_history,useq,vseq);
   maxalignedlen = GT_MULT2(lowfront->row) + FRONT_DIAGONAL(lowfront);
 
   (lowfront+1)->row++;
   (lowfront+1)->backreference = FT_EOP_REPLACEMENT;
-  UPDATE_MATCH_HISTORY((lowfront+1)->matchhistory_count,
-                       (lowfront+1)->matchhistory);
-  add_matches(midfront,lowfront + 1,mask,useq,vseq);
+  GT_UPDATE_MATCH_HISTORY(lowfront+1);
+  front_prune_add_matches(midfront,lowfront + 1,leftmostbit,max_history,
+                          useq,vseq);
   alignedlen = GT_MULT2((lowfront+1)->row) + FRONT_DIAGONAL(lowfront + 1);
   if (maxalignedlen < alignedlen)
   {
@@ -368,9 +454,9 @@ static GtUword front_second_inplace(Frontvalue *midfront,
   }
 
   (lowfront+2)->backreference = FT_EOP_INSERTION;
-  UPDATE_MATCH_HISTORY((lowfront+2)->matchhistory_count,
-                       (lowfront+2)->matchhistory);
-  add_matches(midfront,lowfront + 2,mask,useq,vseq);
+  GT_UPDATE_MATCH_HISTORY(lowfront+2);
+  front_prune_add_matches(midfront,lowfront + 2,leftmostbit,max_history,useq,
+                          vseq);
   alignedlen = GT_MULT2((lowfront+2)->row) + FRONT_DIAGONAL(lowfront + 2);
   if (maxalignedlen < alignedlen)
   {
@@ -379,63 +465,52 @@ static GtUword front_second_inplace(Frontvalue *midfront,
   return maxalignedlen;
 }
 
-#undef TRIM_INFO_OUT
-#ifdef TRIM_INFO_OUT
-static bool trimthisentry(GtUword distance,
+static bool trimthisentry(GT_UNUSED GtUword distance,
                           Rowvaluetype row,
                           GtWord diagonal,
-                          GtUword minlenforhistorycheck,
-                          Matchcounttype matchhistory_count,
-                          GtUword minmatchnum,
+                          const Frontvalue *fv,
+                          GT_UNUSED GtUword max_history,
+                          GtUword minmatchpercentage,
                           GtUword minlenfrommaxdiff)
 {
-  GtUword alignedlen = GT_MULT2(row) + diagonal;
-
-  if (alignedlen >= minlenforhistorycheck && matchhistory_count < minmatchnum)
+  if (fv->matchhistory_count < (fv->matchhistory_size * minmatchpercentage)/100)
   {
-    printf(GT_WD "&" GT_WU "&%u&1: matches=%d < " GT_WU "=minmatches\n",
-              diagonal,distance,row,(int) matchhistory_count,minmatchnum);
-    return true;
-  }
-  if (alignedlen < minlenfrommaxdiff)
-  {
-    printf(GT_WD "&" GT_WU "&%u&2: i'+j'=" GT_WU "<" GT_WU "=i+j-lag\n",
-              diagonal,distance,row,alignedlen,minlenfrommaxdiff);
-    return true;
-  }
-  printf(GT_WD "&" GT_WU "&%u\n", diagonal,distance,row);
-  return false;
-}
-#else
-static bool trimthisentry(Rowvaluetype row,
-                          GtWord diagonal,
-                          GtUword minlenforhistorycheck,
-                          Matchcounttype matchhistory_count,
-                          GtUword minmatchnum,
-                          GtUword minlenfrommaxdiff)
-{
-  GtUword alignedlen = GT_MULT2(row) + diagonal;
-
-  if (alignedlen >= minlenforhistorycheck && matchhistory_count < minmatchnum)
-  {
-    return true;
-  }
-  if (alignedlen < minlenfrommaxdiff)
-  {
-    return true;
-  }
-  return false;
-}
+#undef TRIM_INFO_OUT
+#ifdef TRIM_INFO_OUT
+    GtUword alignedlen = GT_MULT2(row) + diagonal;
+    double identity = 100.0 * (1.0 - 2.0 * (double) distance/alignedlen);
+    printf("aligned=" GT_WU ",diagonal=" GT_WD ", distance=" GT_WU
+           ", row=%u, identity=%.2f, hist_size=%d, matches=%d "
+           "< " GT_WU "=minmatches\n",
+           alignedlen,
+           diagonal,distance,row,
+           identity,
+           (int) fv->matchhistory_size,
+           (int) fv->matchhistory_count,
+           fv->matchhistory_size * minmatchpercentage/100);
 #endif
+    return true;
+  }
+  if (GT_MULT2(row) + diagonal < minlenfrommaxdiff)
+  {
+#ifdef TRIM_INFO_OUT
+    printf(GT_WD "&" GT_WU "&%u&2: i'+j'=" GT_WU "<" GT_WU "=i+j-lag\n",
+              diagonal,distance,row,GT_MULT2(row) + diagonal,minlenfrommaxdiff);
+#endif
+    return true;
+  }
+#ifdef TRIM_INFO_OUT
+  printf(GT_WD "&" GT_WU "&%u\n", diagonal,distance,row);
+#endif
+  return false;
+}
 
 static GtUword trim_front(bool upward,
-#ifdef TRIM_INFO_OUT
                           GtUword distance,
-#endif
                           GtUword ulen,
                           GtUword vlen,
-                          GtUword minmatchnum,
-                          GtUword minlenforhistorycheck,
+                          GtUword max_history,
+                          GtUword minmatchpercentage,
                           GtUword minlenfrommaxdiff,
                           const Frontvalue *midfront,
                           const Frontvalue *from,
@@ -450,16 +525,13 @@ static GtUword trim_front(bool upward,
   {
     if (frontptr->row > ulen ||
         frontptr->row + FRONT_DIAGONAL(frontptr) > vlen ||
-        trimthisentry(
-#ifdef TRIM_INFO_OUT
-                        distance,
-#endif
-                        frontptr->row,
-                        FRONT_DIAGONAL(frontptr),
-                        minlenforhistorycheck,
-                        frontptr->matchhistory_count,
-                        minmatchnum,
-                        minlenfrommaxdiff))
+        trimthisentry(distance,
+                      frontptr->row,
+                      FRONT_DIAGONAL(frontptr),
+                      frontptr,
+                      max_history,
+                      minmatchpercentage,
+                      minlenfrommaxdiff))
     {
       trim++;
     } else
@@ -505,7 +577,7 @@ static void update_trace_and_polished(Polished_point *best_polished_point,
                                       GtUword *minrow,
                                       GtUword *mincol,
 #endif
-                                      Fronttrace *front_trace,
+                                      GtFronttrace *front_trace,
                                       const Polishing_info *pol_info,
                                       GtUword distance,
                                       GtUword trimleft,
@@ -514,7 +586,6 @@ static void update_trace_and_polished(Polished_point *best_polished_point,
                                       Frontvalue *highfront)
 {
   const Frontvalue *frontptr;
-  uint64_t lsb;
 
 #ifndef OUTSIDE_OF_GT
   *minrow = GT_UWORD_MAX;
@@ -523,6 +594,7 @@ static void update_trace_and_polished(Polished_point *best_polished_point,
   for (frontptr = lowfront; frontptr <= highfront; frontptr++)
   {
     GtUword alignedlen = GT_MULT2(frontptr->row) + FRONT_DIAGONAL(frontptr);
+    uint64_t filled_matchhistory_bits;
 
 #ifndef OUTSIDE_OF_GT
     GtUword currentcol;
@@ -539,14 +611,27 @@ static void update_trace_and_polished(Polished_point *best_polished_point,
       *mincol = currentcol;
     }
 #endif
-    lsb = frontptr->matchhistory & pol_info->mask;
-    if (HISTORY_IS_POLISHED(pol_info,frontptr->matchhistory,lsb) &&
-        alignedlen > best_polished_point->alignedlen)
+    if (frontptr->matchhistory_size >= GT_MULT2(pol_info->cut_depth))
+    {
+      filled_matchhistory_bits = frontptr->matchhistory_bits;
+    } else
+    {
+      int shift = GT_MULT2(pol_info->cut_depth) - frontptr->matchhistory_size;
+      uint64_t fill_bits = ((uint64_t) 1 << shift) - 1;
+      filled_matchhistory_bits = frontptr->matchhistory_bits |
+                                 (fill_bits << frontptr->matchhistory_size);
+    }
+    if (alignedlen > best_polished_point->alignedlen &&
+        GT_HISTORY_IS_POLISHED(pol_info,filled_matchhistory_bits))
     {
       best_polished_point->alignedlen = alignedlen;
       best_polished_point->row = frontptr->row;
       best_polished_point->distance = distance;
       best_polished_point->trimleft = trimleft;
+#ifdef TRIM_INFO_OUT
+      printf("new polished point (alignlen=" GT_WU ",row=%u,distance=" GT_WU
+                                ")\n",alignedlen,frontptr->row,distance);
+#endif
     }
     if (front_trace != NULL)
     {
@@ -558,31 +643,32 @@ static void update_trace_and_polished(Polished_point *best_polished_point,
 
 GtUword front_prune_edist_inplace(
 #ifndef OUTSIDE_OF_GT
-                         bool forward,
+                         bool rightextension,
                          GtAllocatedMemory *frontspace,
 #endif
                          Trimstat *trimstat,
                          Polished_point *best_polished_point,
-                         Fronttrace *front_trace,
+                         GtFronttrace *front_trace,
                          const Polishing_info *pol_info,
-                         GtUword history,
-                         GtUword minmatchnum,
+                         GtUword max_history,
+                         GtUword minmatchpercentage,
                          GtUword maxalignedlendifference,
+                         GtUword seedlength,
                          FTsequenceResources *ufsr,
                          GtUword ustart,
                          GtUword ulen,
+                         GtUword vseqstartpos,
                          FTsequenceResources *vfsr,
                          GtUword vstart,
                          GtUword vlen)
 {
   const GtUword sumseqlength = ulen + vlen,
-                minsizeforshift = sumseqlength/1000,
-                minlenforhistorycheck = GT_MULT2(history);
+                minsizeforshift = sumseqlength/1000;
   /* so the space for allocating the fronts is
      sizeof (Frontvalue) * ((m+n)/1000 + maxvalid), where maxvalid is a small
      constant. */
   GtUword distance, trimleft = 0, valid = 1UL, maxvalid = 0, sumvalid = 0;
-  const uint64_t mask = ((uint64_t) 1) << (history-1);
+  const uint64_t leftmostbit = ((uint64_t) 1) << (max_history-1);
   Frontvalue *validbasefront;
   bool diedout = false;
   Sequenceobject useq, vseq;
@@ -592,20 +678,42 @@ GtUword front_prune_edist_inplace(
   frontspace->space = NULL;
   frontspace->allocated = 0;
   frontspace->offset = 0;
-  sequenceobject_init(&useq,useqptr,ustart,ulen);
-  sequenceobject_init(&vseq,vseqptr,vstart,vlen);
+  ft_sequenceobject_init(&useq,useqptr,0,ustart,ulen);
+  ft_sequenceobject_init(&vseq,vseqptr,vseqstartpos,vstart,vlen);
 #else
-  GtReadmode readmode = forward ? GT_READMODE_FORWARD : GT_READMODE_REVERSE;
-  sequenceobject_init(&useq,ufsr->extend_char_access,ufsr->encseq,readmode,
-                      ustart,ulen,ufsr->encseq_r,ufsr->sequence_cache,
-                      ufsr->totallength);
-  sequenceobject_init(&vseq,ufsr->extend_char_access,vfsr->encseq,readmode,
-                      vstart,vlen,vfsr->encseq_r,vfsr->sequence_cache,
-                      vfsr->totallength);
-  frontspace->offset = 0;
+  /*
+  printf("%sextension:useq->readmode=%s,vseq->readmode=%s\n",
+          rightextension ? "right" : "left",
+          gt_readmode_show(ufsr->readmode),gt_readmode_show(ufsr->readmode));
+  */
+  ft_sequenceobject_init(&useq,
+                         ufsr->extend_char_access,
+                         ufsr->encseq,
+                         rightextension,
+                         ufsr->readmode,
+                         0,
+                         ustart,
+                         ulen,
+                         ufsr->encseq_r,
+                         ufsr->sequence_cache,
+                         NULL,
+                         ufsr->totallength);
+  ft_sequenceobject_init(&vseq,
+                         vfsr->extend_char_access,
+                         vfsr->encseq,
+                         rightextension,
+                         vfsr->readmode,
+                         vseqstartpos,
+                         vstart,
+                         vlen,
+                         vfsr->encseq_r,
+                         vfsr->sequence_cache,
+                         vfsr->bytesequence,
+                         vfsr->totallength);
+#ifdef SKDEBUG
+  gt_greedy_show_context(rightextension,&useq,&vseq);
 #endif
-#ifdef TRIM_INFO_OUT
-  printf("regionalquality(minmatchnum)=" GT_WU "\n",minmatchnum);
+  frontspace->offset = 0;
 #endif
   for (distance = 0, valid = 1UL; /* Nothing */; distance++, valid += 2)
   {
@@ -628,10 +736,18 @@ GtUword front_prune_edist_inplace(
     if (distance == 0)
     {
       validbasefront->row = 0;
-      validbasefront->matchhistory = 0;
-      validbasefront->matchhistory_count = 0;
+      if (seedlength >= sizeof (validbasefront->matchhistory_bits) * CHAR_BIT)
+      {
+        validbasefront->matchhistory_bits = ~((uint64_t) 0);
+      } else
+      {
+        validbasefront->matchhistory_bits = (((uint64_t) 1) << seedlength) - 1;
+      }
+      validbasefront->matchhistory_size
+        = validbasefront->matchhistory_count = MIN(max_history,seedlength);
       validbasefront->backreference = 0; /* No back reference */
-      add_matches(validbasefront + distance,validbasefront,mask,&useq,&vseq);
+      front_prune_add_matches(validbasefront + distance,validbasefront,
+                              leftmostbit,max_history,&useq,&vseq);
       maxalignedlen = GT_MULT2(validbasefront->row);
     } else
     {
@@ -649,7 +765,7 @@ GtUword front_prune_edist_inplace(
         maxalignedlen
           = front_second_inplace(validbasefront + distance,
                                  validbasefront + trimleft,
-                                 history,
+                                 max_history,
                                  &useq,
                                  &vseq);
       } else
@@ -658,7 +774,7 @@ GtUword front_prune_edist_inplace(
           = front_next_inplace(validbasefront + distance,
                                validbasefront + trimleft,
                                validbasefront + trimleft + valid - 1,
-                               history,
+                               max_history,
                                &useq,
                                &vseq);
       }
@@ -672,13 +788,11 @@ GtUword front_prune_edist_inplace(
            maxalignedlen,minlenfrommaxdiff);
 #endif
     trim = trim_front(true,
-#ifdef TRIM_INFO_OUT
                       distance,
-#endif
                       ulen,
                       vlen,
-                      minmatchnum,
-                      minlenforhistorycheck,
+                      max_history,
+                      minmatchpercentage,
                       minlenfrommaxdiff,
                       validbasefront + distance,
                       validbasefront + trimleft,
@@ -695,13 +809,11 @@ GtUword front_prune_edist_inplace(
     if (valid > 0)
     {
       trim = trim_front(false,
-#ifdef TRIM_INFO_OUT
                         distance,
-#endif
                         ulen,
                         vlen,
-                        minmatchnum,
-                        minlenforhistorycheck,
+                        max_history,
+                        minmatchpercentage,
                         minlenfrommaxdiff,
                         validbasefront + distance,
                         validbasefront + trimleft + valid - 1,
@@ -763,5 +875,9 @@ GtUword front_prune_edist_inplace(
                0
 #endif
               );
+#ifdef OUTSIDE_OF_GT
+  gt_free(frontspace->space);
+  gt_free(frontspace);
+#endif
   return diedout ? sumseqlength + 1 : distance;
 }
