@@ -2,9 +2,11 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <stdbool.h>
+#include <limits.h>
 #include "core/assert_api.h"
 #include "core/ma_api.h"
 #include "core/types_api.h"
+#include "core/minmax.h"
 #include "ft-polish.h"
 
 static void fill_polishing_info(Polishing_info *pol_info,
@@ -32,42 +34,51 @@ static void fill_polishing_info(Polishing_info *pol_info,
   }
 }
 
-Polishing_info *polishing_info_new(GtUword cut_depth,
-                                   double errorpercentage)
+Polishing_info *polishing_info_new_with_bias(double errorpercentage,
+                                             double matchscore_bias,
+                                             GtUword history_size)
 {
   Polishing_info *pol_info = gt_malloc(sizeof *pol_info);
-  GtUword maxshift_for_INT16 = (GtUword) 15;
 
-  if (cut_depth > maxshift_for_INT16)
-  {
-    cut_depth = maxshift_for_INT16;
-  }
   gt_assert(pol_info != NULL);
-  pol_info->entries = 1UL << cut_depth;
+  if (history_size == 0)
+  {
+    pol_info->cut_depth = (GtUword) 15;
+  } else
+  {
+    pol_info->cut_depth = MIN(history_size/2,(GtUword) 15);
+  }
+  pol_info->entries = 1UL << pol_info->cut_depth;
   pol_info->mask = pol_info->entries - 1;
   pol_info->values = gt_malloc(sizeof *pol_info->values * pol_info->entries);
   gt_assert(pol_info->values != NULL);
-  pol_info->cut_depth = cut_depth;
-  pol_info->match_score = 20.0 * errorpercentage;
+  pol_info->match_score = 20.0 * errorpercentage * matchscore_bias;
   gt_assert(pol_info->match_score <= 1000.0);
   pol_info->difference_score = 1000.0 - pol_info->match_score;
   fill_polishing_info(pol_info,0,0,0,0);
   return pol_info;
 }
 
+Polishing_info *polishing_info_new(double errorpercentage,
+                                   GtUword history_size)
+{
+  return polishing_info_new_with_bias(errorpercentage,1.0,history_size);
+}
+
 uint64_t polishing_info_maxvalue(const Polishing_info *pol_info)
 {
   return (((uint64_t) 1) << (2 * pol_info->cut_depth)) - 1;
 }
 
-static char *intbits2string(GtUword bits,GtUword bs)
+static char *polish_intbits2string(GtUword bits,GtUword bs)
 {
   char *csptr;
   GtUword mask;
   static char cs[64+1];
 
-  gt_assert(bits > 0);
-  for (csptr = cs, mask = 1 << (bits-1); mask > 0; mask >>= 1, csptr++)
+  gt_assert(bits > 0 && bits <= sizeof (GtUword) * CHAR_BIT);
+  for (csptr = cs, mask = ((GtUword) 1) << (bits-1); mask > 0;
+       mask >>= 1, csptr++)
   {
      *csptr = (bs & mask) ? '1' : '0';
   }
@@ -83,10 +94,11 @@ void polishing_info_show(const Polishing_info *pol_info)
   printf("pi->entries=" GT_WU "\n",pol_info->entries);
   printf("pi->match_score=" GT_WD "\n",pol_info->match_score);
   printf("pi->difference_score=" GT_WD "\n",pol_info->difference_score);
-  printf("pi->mask=%s\n",intbits2string(pol_info->cut_depth,pol_info->mask));
+  printf("pi->mask=%s\n",
+         polish_intbits2string(pol_info->cut_depth,pol_info->mask));
   for (idx = 0; idx < pol_info->entries; idx++)
   {
-    printf("[%s]=%+hd/%+hd\n",intbits2string(pol_info->cut_depth,idx),
+    printf("[%s]=%+hd/%+hd\n",polish_intbits2string(pol_info->cut_depth,idx),
                               pol_info->values[idx].score_sum,
                               pol_info->values[idx].diff_from_max);
   }
@@ -102,7 +114,8 @@ void polishing_info_delete(Polishing_info *pol_info)
 }
 
 bool history_is_polished_brute_force(const Polishing_info *pol_info,
-                                     uint64_t matchhistory)
+                                     uint64_t matchhistory,
+                                     bool withoutput)
 {
   GtUword idx;
   uint64_t mask;
@@ -118,6 +131,10 @@ bool history_is_polished_brute_force(const Polishing_info *pol_info,
     {
       sum_score -= pol_info->difference_score;
     }
+    if (withoutput)
+    {
+      printf(GT_WU ": sum_score=" GT_WD "\n",idx,sum_score);
+    }
     if (sum_score < 0)
     {
       return false;
