@@ -48,7 +48,7 @@ struct GtIndexOptions
 {
   unsigned int numofparts,
                prefixlength;
-  unsigned long maximumspace;
+  GtUword maximumspace;
   GtStrArray *algbounds;
   GtReadmode readmode;
   bool outsuftab,
@@ -130,13 +130,13 @@ static GtIndexOptions* gt_index_options_new(void)
         if (!haserr)\
         {\
           arg = gt_str_array_get(algbounds, IDX);\
-          if (sscanf(arg,"%ld", &readint) != 1 || readint <= 0)\
+          if (sscanf(arg,""GT_WD"", &readint) != 1 || readint <= 0)\
           {\
             gt_error_set(err,"option -algbds: all arguments must be positive " \
                              "numbers");\
             haserr = true;\
           }\
-          sfxstrategy->COMP = (unsigned long) readint;\
+          sfxstrategy->COMP = (GtUword) readint;\
         }
 
 int gt_parse_algbounds(Sfxstrategy *sfxstrategy,
@@ -145,7 +145,7 @@ int gt_parse_algbounds(Sfxstrategy *sfxstrategy,
 {
   bool haserr = false;
   const char *arg;
-  long readint;
+  GtWord readint;
 
   if (gt_str_array_size(algbounds) != 3UL)
   {
@@ -403,7 +403,7 @@ static GtIndexOptions* gt_index_options_register_generic_create(
   gt_option_is_development_option(idxo->optionnoshortreadsort);
   gt_option_parser_add_option(op, idxo->optionnoshortreadsort);
 
-  idxo->optionmaxwidthrealmedian = gt_option_new_ulong("maxwidthrealmedian",
+  idxo->optionmaxwidthrealmedian = gt_option_new_uword("maxwidthrealmedian",
                                                  "compute real median for "
                                                  "intervals of at most the "
                                                  "given widthprefixes",
@@ -507,6 +507,14 @@ static GtIndexOptions* gt_index_options_register_generic_create(
   gt_option_is_development_option(idxo->option);
   gt_option_parser_add_option(op, idxo->option);
 
+  idxo->option = gt_option_new_bool("compressedoutput",
+                                    "output suftab and lcptab in compressed "
+                                    "form",
+                                    &idxo->sfxstrategy.compressedoutput,
+                                    false);
+  gt_option_is_development_option(idxo->option);
+  gt_option_parser_add_option(op, idxo->option);
+
   gt_option_parser_register_hook(op, gt_index_options_check_set_create_opts,
                                  idxo);
   return idxo;
@@ -583,7 +591,7 @@ GT_INDEX_OPTS_GETTER_DEF(prefixlength, unsigned int);
 GT_INDEX_OPTS_GETTER_DEF_OPT(spmopt);
 /* these are available as values only, set _after_ option processing */
 GT_INDEX_OPTS_GETTER_DEF_VAL(lcpdist, bool);
-GT_INDEX_OPTS_GETTER_DEF_VAL(maximumspace, unsigned long);
+GT_INDEX_OPTS_GETTER_DEF_VAL(maximumspace, GtUword);
 GT_INDEX_OPTS_GETTER_DEF_VAL(numofparts, unsigned int);
 GT_INDEX_OPTS_GETTER_DEF_VAL(outkyssort, bool);
 GT_INDEX_OPTS_GETTER_DEF_VAL(outkystab, bool);
