@@ -18,14 +18,14 @@
 #include "core/ma_api.h"
 #include "core/unused_api.h"
 #include "core/types_api.h"
+#include "core/minmax.h"
 #include "extended/alignment.h"
 #include "extended/linearalign.h"
-#undef SKDEBUG
-#ifdef SKDEBUG
-#include "match/greedyedist.h"
-#endif
-#include "querymatch-align.h"
+#include "extended/linspace_management.h"
+#include "revcompl.h"
 #include "seed-extend.h"
+#include "ft-polish.h"
+#include "querymatch-align.h"
 
 static void eoplist_reverse_order(uint8_t *start,uint8_t *end)
 {
@@ -106,11 +106,11 @@ void gt_querymatch_showeoplist(const GtArrayuint8_t *eoplist)
 struct GtQuerymatchoutoptions
 {
   GtUword totallength,
-          alignmentwidth, /* if > 0, then with alignment of this width */
+          alignmentwidth,
           useqbuffer_size,
           vseqbuffer_size;
   GtArrayuint8_t eoplist;
-  Fronttrace *front_trace;
+  GtFronttrace *front_trace;
   GtGreedyextendmatchinfo *ggemi;
   GtUchar *useqbuffer, *vseqbuffer, *alignment_show_buffer;
   const GtUchar *characters;
@@ -118,20 +118,24 @@ struct GtQuerymatchoutoptions
   GtEncseqReader *esr_for_align_show;
   GtUchar wildcardshow;
   GtSeqpaircoordinates correction_info;
+  GtLinspaceManagement *linspace_spacemanager;
+  GtScoreHandler *linspace_scorehandler;
+  bool always_polished_ends,
+       generatealignment,
+       showeoplist;
+  Polishing_info *pol_info;
 };
 
-GtQuerymatchoutoptions *gt_querymatchoutoptions_new(
-                                GtUword alignmentwidth,
-                                GtUword errorpercentage,
-                                GtUword maxalignedlendifference,
-                                GtUword history,
-                                GtUword perc_mat_history,
-                                GtExtendCharAccess extend_char_access,
-                                GtUword sensitivity)
+GtQuerymatchoutoptions *gt_querymatchoutoptions_new(bool generatealignment,
+                                                    bool showeoplist,
+                                                    GtUword alignmentwidth)
 {
   GtQuerymatchoutoptions *querymatchoutoptions
     = gt_malloc(sizeof *querymatchoutoptions);
 
+  querymatchoutoptions->generatealignment
+    = generatealignment || alignmentwidth > 0 || showeoplist;
+  querymatchoutoptions->showeoplist = showeoplist;
   querymatchoutoptions->alignmentwidth = alignmentwidth;
   querymatchoutoptions->front_trace = NULL;
   querymatchoutoptions->ggemi = NULL;
@@ -144,31 +148,93 @@ GtQuerymatchoutoptions *gt_querymatchoutoptions_new(
   querymatchoutoptions->esr_for_align_show = NULL;
   querymatchoutoptions->characters = NULL;
   querymatchoutoptions->alignment = NULL;
+  querymatchoutoptions->linspace_spacemanager = NULL;
+  querymatchoutoptions->linspace_scorehandler = NULL;
+  querymatchoutoptions->always_polished_ends = true;
+  querymatchoutoptions->alignment_show_buffer = NULL;
+  if (generatealignment)
+  {
+    querymatchoutoptions->alignment = gt_alignment_new();
+  }
   if (alignmentwidth > 0)
   {
     querymatchoutoptions->alignment_show_buffer
       = gt_alignment_buffer_new(alignmentwidth);
-  } else
-  {
-    querymatchoutoptions->alignment_show_buffer = NULL;
+    querymatchoutoptions->linspace_spacemanager = gt_linspaceManagement_new();
+    querymatchoutoptions->linspace_scorehandler = gt_scorehandler_new(0,1,0,1);
   }
+  return querymatchoutoptions;
+}
+
+void gt_querymatchoutoptions_extend(
+                  GtQuerymatchoutoptions *querymatchoutoptions,
+                  GtUword errorpercentage,
+                  GtUword maxalignedlendifference,
+                  GtUword history_size,
+                  GtUword perc_mat_history,
+                  GtExtendCharAccess extend_char_access,
+                  bool weakends,
+                  GtUword sensitivity,
+                  double matchscore_bias,
+                  bool always_polished_ends,
+                  bool seed_display)
+{
   if (errorpercentage > 0)
   {
-    if (alignmentwidth > 0)
+    gt_assert(querymatchoutoptions != NULL);
+    if (querymatchoutoptions->generatealignment)
     {
       querymatchoutoptions->front_trace = front_trace_new();
-      querymatchoutoptions->alignment = gt_alignment_new();
     }
+    querymatchoutoptions->pol_info
+      = polishing_info_new_with_bias(weakends ? MAX(errorpercentage,20)
+                                              : errorpercentage,
+                                     matchscore_bias,
+                                     history_size);
     querymatchoutoptions->ggemi
       = gt_greedy_extend_matchinfo_new(errorpercentage,
                                        maxalignedlendifference,
-                                       history, /* default value */
+                                       history_size, /* default value */
                                        perc_mat_history,
                                        0,/* userdefinedleastlength not used */
                                        extend_char_access,
-                                       sensitivity);
+                                       sensitivity,
+                                       querymatchoutoptions->pol_info);
+    if (querymatchoutoptions->alignment != NULL)
+    {
+      if (always_polished_ends)
+      {
+        gt_alignment_polished_ends(querymatchoutoptions->alignment,
+                                   querymatchoutoptions->pol_info,true);
+      }
+      if (seed_display)
+      {
+        gt_alignment_seed_display_set(querymatchoutoptions->alignment);
+      }
+    }
+    querymatchoutoptions->always_polished_ends = always_polished_ends;
   }
-  return querymatchoutoptions;
+}
+
+void gt_querymatchoutoptions_for_align_only(
+                  GtQuerymatchoutoptions *querymatchoutoptions,
+                  GtUword errorpercentage,
+                  double matchscore_bias,
+                  GtUword history_size,
+                  bool always_polished_ends,
+                  bool seed_display)
+{
+  gt_querymatchoutoptions_extend(querymatchoutoptions,
+                                 errorpercentage,
+                                 GT_MAX_ALI_LEN_DIFF,
+                                 history_size,
+                                 GT_MIN_PERC_MAT_HISTORY,
+                                 GT_EXTEND_CHAR_ACCESS_ANY,
+                                 false,
+                                 100,
+                                 matchscore_bias,
+                                 always_polished_ends,
+                                 seed_display);
 }
 
 void gt_querymatchoutoptions_delete(
@@ -179,33 +245,46 @@ void gt_querymatchoutoptions_delete(
     front_trace_delete(querymatchoutoptions->front_trace);
     gt_greedy_extend_matchinfo_delete(querymatchoutoptions->ggemi);
     gt_free(querymatchoutoptions->useqbuffer);
-    gt_free(querymatchoutoptions->vseqbuffer);
+    if (querymatchoutoptions->vseqbuffer_size > 0)
+    {
+      gt_free(querymatchoutoptions->vseqbuffer);
+    }
     gt_alignment_delete(querymatchoutoptions->alignment);
     GT_FREEARRAY(&querymatchoutoptions->eoplist,uint8_t);
     gt_alignment_buffer_delete(querymatchoutoptions->alignment_show_buffer);
     gt_encseq_reader_delete(querymatchoutoptions->esr_for_align_show);
+    gt_linspaceManagement_delete(querymatchoutoptions->linspace_spacemanager);
+    gt_scorehandler_delete(querymatchoutoptions->linspace_scorehandler);
+    polishing_info_delete(querymatchoutoptions->pol_info);
     gt_free(querymatchoutoptions);
   }
 }
 
-static bool seededmatch2eoplist(GtUword dbstart,
+static bool seededmatch2eoplist(GtQuerymatchoutoptions *querymatchoutoptions,
+                                const GtEncseq *encseq,
+                                const GtSeqorEncseq *query,
+                                GtReadmode query_readmode,
+                                GtUword query_seqstartpos,
+                                GtUword query_totallength,
+                                GtUword dbstart,
                                 GtUword dblen,
-                                GtUword querystartabsolute,
+                                GtUword abs_querystart,
                                 GtUword querylen,
                                 GtUword seedpos1,
                                 GtUword seedpos2,
                                 GtUword seedlen,
-                                bool greedyextension,
-                                GtQuerymatchoutoptions *querymatchoutoptions,
-                                const GtEncseq *encseq)
+                                bool greedyextension)
 {
   GtUword ulen, vlen, ustart, vstart;
   bool alignment_succeeded = true;
   Polished_point right_best_polished_point = {0,0,0};
   Polished_point left_best_polished_point = {0,0,0};
+  GtUword pol_size;
   GtSeqpaircoordinates *coords;
 
-  gt_assert(querymatchoutoptions != NULL);
+  gt_assert(querymatchoutoptions != NULL &&
+            querymatchoutoptions->pol_info != NULL);
+  pol_size = GT_MULT2(querymatchoutoptions->pol_info->cut_depth);
   querymatchoutoptions->eoplist.nextfreeuint8_t = 0;
   if (querymatchoutoptions->totallength == GT_UWORD_MAX)
   {
@@ -215,16 +294,21 @@ static bool seededmatch2eoplist(GtUword dbstart,
   vstart = seedpos2 + seedlen;
   gt_assert(dbstart + dblen >= ustart);
   ulen = dbstart + dblen - ustart;
-  gt_assert(querystartabsolute + querylen >= vstart);
-  vlen = querystartabsolute + querylen - vstart;
+  gt_assert(abs_querystart + querylen >= vstart);
+  vlen = abs_querystart + querylen - vstart;
   if (ulen > 0 && vlen > 0)
   {
     if (gt_align_front_prune_edist(true,
                                    &right_best_polished_point,
                                    querymatchoutoptions->front_trace,
                                    encseq,
+                                   query,
+                                   query_readmode,
+                                   query_seqstartpos,
+                                   query_totallength,
                                    querymatchoutoptions->ggemi,
                                    greedyextension,
+                                   seedlen,
                                    ustart,
                                    ulen,
                                    vstart,
@@ -235,40 +319,49 @@ static bool seededmatch2eoplist(GtUword dbstart,
     {
       if (querymatchoutoptions->front_trace != NULL)
       {
-        front_trace2eoplist(&querymatchoutoptions->eoplist,
+        front_trace2eoplist(querymatchoutoptions->always_polished_ends,
+                            &querymatchoutoptions->eoplist,
                             querymatchoutoptions->front_trace,
                             &right_best_polished_point,
+                            pol_size,
+                            querymatchoutoptions->pol_info->match_score,
+                            querymatchoutoptions->pol_info->difference_score,
+                            NULL,
                             ulen,
+                            NULL,
                             vlen);
       }
     }
     if (querymatchoutoptions->front_trace != NULL)
     {
-      gt_assert(querymatchoutoptions->alignmentwidth > 0);
+      gt_assert(querymatchoutoptions->generatealignment);
       front_trace_reset(querymatchoutoptions->front_trace,ulen+vlen);
     }
   }
   if (alignment_succeeded)
   {
-    if (querymatchoutoptions->alignmentwidth > 0)
+    if (querymatchoutoptions->generatealignment)
     {
       front_trace_multireplacement(&querymatchoutoptions->eoplist,seedlen);
     }
-    if (seedpos1 > dbstart && seedpos2 > querystartabsolute)
+    if (seedpos1 > dbstart && seedpos2 > abs_querystart)
     {
-      ustart = GT_REVERSEPOS(querymatchoutoptions->totallength,seedpos1 - 1);
       ulen = seedpos1 - dbstart;
-      vstart = GT_REVERSEPOS(querymatchoutoptions->totallength,seedpos2-1);
-      vlen = seedpos2 - querystartabsolute;
+      vlen = seedpos2 - abs_querystart;
       if (gt_align_front_prune_edist(false,
                                      &left_best_polished_point,
                                      querymatchoutoptions->front_trace,
                                      encseq,
+                                     query,
+                                     query_readmode,
+                                     query_seqstartpos,
+                                     query_totallength,
                                      querymatchoutoptions->ggemi,
                                      greedyextension,
-                                     ustart,
+                                     seedlen,
+                                     dbstart,
                                      ulen,
-                                     vstart,
+                                     abs_querystart,
                                      vlen) == ulen + vlen + 1)
       {
         alignment_succeeded = false;
@@ -277,10 +370,17 @@ static bool seededmatch2eoplist(GtUword dbstart,
         if (querymatchoutoptions->front_trace != NULL)
         {
           GtUword eoplistlen = querymatchoutoptions->eoplist.nextfreeuint8_t;
-          front_trace2eoplist(&querymatchoutoptions->eoplist,
+
+          front_trace2eoplist(querymatchoutoptions->always_polished_ends,
+                              &querymatchoutoptions->eoplist,
                               querymatchoutoptions->front_trace,
                               &left_best_polished_point,
+                              pol_size,
+                              querymatchoutoptions->pol_info->match_score,
+                              querymatchoutoptions->pol_info->difference_score,
+                              NULL,
                               ulen,
+                              NULL,
                               vlen);
           eoplist_reverse_order(querymatchoutoptions->eoplist.spaceuint8_t +
                                  eoplistlen,
@@ -309,8 +409,8 @@ static bool seededmatch2eoplist(GtUword dbstart,
     rightcolumn = right_best_polished_point.alignedlen -
                   right_best_polished_point.row;
     gt_assert(seedpos2 >= leftcolumn &&
-              querystartabsolute <= seedpos2 - leftcolumn);
-    coords->voffset = seedpos2 - leftcolumn - querystartabsolute;
+              abs_querystart <= seedpos2 - leftcolumn);
+    coords->voffset = seedpos2 - leftcolumn - abs_querystart;
     coords->vlen = seedlen + leftcolumn + rightcolumn;
     coords->sumdist = left_best_polished_point.distance +
                       right_best_polished_point.distance;
@@ -324,32 +424,17 @@ static bool seededmatch2eoplist(GtUword dbstart,
   return alignment_succeeded;
 }
 
-#ifdef SKDEBUG
-static void check_correct_edist(const GtUchar *useq,
-                                GtUword ulen,
-                                const GtUchar *vseq,
-                                GtUword vlen,
-                                GtUword edist)
-{
-  GtUword realedist;
-  GtFrontResource *ftres = gt_frontresource_new(edist);
-  GtSeqabstract *useq_abstract = gt_seqabstract_new_gtuchar(useq, ulen, 0);
-  GtSeqabstract *vseq_abstract = gt_seqabstract_new_gtuchar(vseq, vlen, 0);
-
-  realedist = greedyunitedist(ftres,useq_abstract,vseq_abstract);
-  gt_assert(realedist <= edist);
-  gt_seqabstract_delete(useq_abstract);
-  gt_seqabstract_delete(vseq_abstract);
-  gt_frontresource_delete(ftres);
-}
-#endif
-
 bool gt_querymatchoutoptions_alignment_prepare(GtQuerymatchoutoptions
                                                 *querymatchoutoptions,
                                                const GtEncseq *encseq,
+                                               const GtSeqorEncseq *query,
+                                               GtReadmode query_readmode,
+                                               GtUword query_seqstartpos,
+                                               GtUword query_totallength,
                                                GtUword dbstart,
                                                GtUword dblen,
-                                               GtUword querystartabsolute,
+                                               GtUword abs_querystart,
+                                               GtUword abs_querystart_fwdstrand,
                                                GtUword querylen,
                                                GtUword edist,
                                                GtUword seedpos1,
@@ -388,34 +473,83 @@ bool gt_querymatchoutoptions_alignment_prepare(GtQuerymatchoutoptions
                             querymatchoutoptions->useqbuffer,
                             dbstart,
                             dbstart + dblen - 1);
-  if (edist > 0)
+  if ((query == NULL || query->seq == NULL ||
+       query_readmode != GT_READMODE_FORWARD) &&
+      querylen > querymatchoutoptions->vseqbuffer_size)
   {
-    if (querylen > querymatchoutoptions->vseqbuffer_size)
+    querymatchoutoptions->vseqbuffer
+      = gt_realloc(querymatchoutoptions->vseqbuffer,
+                   sizeof *querymatchoutoptions->vseqbuffer * querylen);
+    querymatchoutoptions->vseqbuffer_size = querylen;
+  }
+  if (query == NULL || query->seq == NULL)
+  {
+    gt_assert(query == NULL || query->encseq != NULL);
+    gt_encseq_extract_encoded_with_reader(
+                            querymatchoutoptions->esr_for_align_show,
+                            query == NULL ? encseq : query->encseq,
+                            querymatchoutoptions->vseqbuffer,
+                            abs_querystart_fwdstrand,
+                            abs_querystart_fwdstrand + querylen - 1);
+  } else
+  {
+    if (query_readmode == GT_READMODE_FORWARD)
     {
       querymatchoutoptions->vseqbuffer
-        = gt_realloc(querymatchoutoptions->vseqbuffer,
-                     sizeof *querymatchoutoptions->vseqbuffer * querylen);
-      querymatchoutoptions->vseqbuffer_size = querylen;
+        = (GtUchar *) (query->seq + abs_querystart_fwdstrand);
+    } else
+    {
+      memcpy(querymatchoutoptions->vseqbuffer,
+             query->seq + abs_querystart_fwdstrand,
+             querylen * sizeof *querymatchoutoptions->vseqbuffer);
     }
-    gt_encseq_extract_encoded_with_reader(
-                              querymatchoutoptions->esr_for_align_show,
-                              encseq,
-                              querymatchoutoptions->vseqbuffer,
-                              querystartabsolute,
-                              querystartabsolute + querylen - 1);
-    if (seededmatch2eoplist(dbstart,
+  }
+  if (query_readmode == GT_READMODE_REVERSE)
+  {
+    gt_inplace_reverse(querymatchoutoptions->vseqbuffer,querylen);
+  } else
+  {
+    if (query_readmode == GT_READMODE_REVCOMPL)
+    {
+      gt_inplace_reverse_complement(querymatchoutoptions->vseqbuffer,
+                                    querylen);
+    } else
+    {
+      if (query_readmode == GT_READMODE_COMPL)
+      {
+        gt_inplace_complement(querymatchoutoptions->vseqbuffer,querylen);
+      }
+    }
+  }
+  if (edist > 0)
+  {
+    if (seededmatch2eoplist(querymatchoutoptions,
+                            encseq,
+                            query,
+                            query_readmode,
+                            query_seqstartpos,
+                            query_totallength,
+                            dbstart,
                             dblen,
-                            querystartabsolute,
+                            abs_querystart,
                             querylen,
                             seedpos1,
                             seedpos2,
                             seedlen,
-                            greedyextension,
-                            querymatchoutoptions,
-                            encseq))
+                            greedyextension))
     {
+      if (querymatchoutoptions->generatealignment)
+      {
+        gt_alignment_reset(querymatchoutoptions->alignment);
+        converteoplist2alignment(querymatchoutoptions->alignment,
+                                 &querymatchoutoptions->eoplist);
+      }
       if (querymatchoutoptions->alignmentwidth > 0)
       {
+        gt_assert(dbstart <= seedpos1);
+        gt_alignment_set_seedoffset(querymatchoutoptions->alignment,
+                                    seedpos1 - dbstart,
+                                    seedlen);
         gt_alignment_set_seqs(querymatchoutoptions->alignment,
                               querymatchoutoptions->useqbuffer +
                                   querymatchoutoptions->correction_info.uoffset,
@@ -423,13 +557,11 @@ bool gt_querymatchoutoptions_alignment_prepare(GtQuerymatchoutoptions
                               querymatchoutoptions->vseqbuffer +
                                   querymatchoutoptions->correction_info.voffset,
                               querymatchoutoptions->correction_info.vlen);
-        converteoplist2alignment(querymatchoutoptions->alignment,
-                                 &querymatchoutoptions->eoplist);
       }
       seededalignment = true;
     } else
     {
-      if (querymatchoutoptions->alignmentwidth > 0)
+      if (querymatchoutoptions->generatealignment)
       {
 #ifndef NDEBUG
         GtUword linedist;
@@ -445,58 +577,81 @@ bool gt_querymatchoutoptions_alignment_prepare(GtQuerymatchoutoptions
 #else
         (void)
 #endif
-                   gt_computelinearspace(querymatchoutoptions->alignment,
-                                         querymatchoutoptions->useqbuffer,
-                                         0,
-                                         dblen,
-                                         querymatchoutoptions->vseqbuffer,
-                                         0,
-                                         querylen,
-                                         0,
-                                         1,
-                                         1);
+        gt_computelinearspace_generic(
+                              querymatchoutoptions->linspace_spacemanager,
+                              querymatchoutoptions->linspace_scorehandler,
+                              querymatchoutoptions->alignment,
+                              querymatchoutoptions->useqbuffer,
+                              0,
+                              dblen,
+                              querymatchoutoptions->vseqbuffer,
+                              0,
+                              querylen);
         gt_assert(linedist <= edist);
-        /*printf("linedist = " GT_WU " <= " GT_WU "= edist\n",linedist,edist);*/
       }
     }
-#ifdef SKDEBUG
-    check_correct_edist(querymatchoutoptions->useqbuffer,
-                        dblen,
-                        querymatchoutoptions->vseqbuffer,
-                        querylen,
-                        edist);
-#endif
+  } else
+  {
+    if (querymatchoutoptions->alignmentwidth > 0)
+    {
+      gt_alignment_set_seqs(querymatchoutoptions->alignment,
+                            querymatchoutoptions->useqbuffer,
+                            dblen,
+                            querymatchoutoptions->vseqbuffer,
+                            querylen);
+    }
   }
   return seededalignment;
 }
 
 void gt_querymatchoutoptions_alignment_show(const GtQuerymatchoutoptions
                                               *querymatchoutoptions,
-                                            GT_UNUSED bool selfmatch,
-                                            GtUword edist,
-                                            GtUword len)
+                                            GtUword distance,
+                                            GT_UNUSED bool verify_alignment)
 {
-  if (querymatchoutoptions != NULL && querymatchoutoptions->alignmentwidth > 0)
+  if (querymatchoutoptions != NULL)
   {
-    gt_assert(selfmatch);
-    if (edist > 0)
+    if (querymatchoutoptions->alignmentwidth > 0)
     {
-      gt_alignment_show_generic(querymatchoutoptions->alignment_show_buffer,
+      if (distance > 0)
+      {
+        gt_alignment_show_generic(querymatchoutoptions->alignment_show_buffer,
+                                  false,
+                                  querymatchoutoptions->alignment,
+                                  stdout,
+                                  (unsigned int)
+                                  querymatchoutoptions->alignmentwidth,
+                                  querymatchoutoptions->characters,
+                                  querymatchoutoptions->wildcardshow);
+      } else
+      {
+        gt_alignment_exact_show(querymatchoutoptions->alignment_show_buffer,
                                 querymatchoutoptions->alignment,
                                 stdout,
-                                (unsigned int)
                                 querymatchoutoptions->alignmentwidth,
-                                querymatchoutoptions->characters,
-                                querymatchoutoptions->wildcardshow);
-      gt_alignment_reset(querymatchoutoptions->alignment);
-    } else
+                                querymatchoutoptions->characters);
+      }
+      if (verify_alignment)
+      {
+        (void) gt_alignment_check_edist(querymatchoutoptions->alignment,
+                                        distance,NULL);
+      }
+    }
+    if (querymatchoutoptions->showeoplist)
     {
-      gt_alignment_exact_show(querymatchoutoptions->alignment_show_buffer,
-                              querymatchoutoptions->useqbuffer,
-                              len,
-                              stdout,
-                              querymatchoutoptions->alignmentwidth,
-                              querymatchoutoptions->characters);
+      if (distance > 0)
+      {
+        gt_alignment_show_multieop_list(querymatchoutoptions->alignment,
+                                        stdout);
+      } else
+      {
+        printf("[]\n");
+      }
+    }
+    if (querymatchoutoptions->alignmentwidth > 0 ||
+        querymatchoutoptions->showeoplist)
+    {
+      gt_alignment_reset(querymatchoutoptions->alignment);
     }
   }
 }
@@ -504,5 +659,13 @@ void gt_querymatchoutoptions_alignment_show(const GtQuerymatchoutoptions
 const GtSeqpaircoordinates *gt_querymatchoutoptions_correction_get(
               const GtQuerymatchoutoptions *querymatchoutoptions)
 {
+  gt_assert(querymatchoutoptions != NULL);
   return &querymatchoutoptions->correction_info;
 }
+
+const GtAlignment *gt_querymatchoutoptions_alignment_get(
+              const GtQuerymatchoutoptions *querymatchoutoptions)
+{
+  gt_assert(querymatchoutoptions != NULL);
+  return querymatchoutoptions->alignment;
+}
