@@ -23,51 +23,64 @@
 #include "core/readmode.h"
 #include "core/encseq.h"
 #include "core/unused_api.h"
+#include "core/arraydef.h"
 #include "querymatch-align.h"
+#include "seq_or_encseq.h"
 
 typedef struct GtQuerymatch GtQuerymatch;
 
-GtQuerymatch *gt_querymatch_new(GtQuerymatchoutoptions *querymatchoutoptions);
+GT_DECLAREARRAYSTRUCT(GtQuerymatch);
+
+GtQuerymatch *gt_querymatch_new(void);
+
+void gt_querymatch_seed_display_set(GtQuerymatch *querymatch);
+
+void gt_querymatch_outoptions_set(GtQuerymatch *querymatch,
+                GtQuerymatchoutoptions *querymatchoutoptions);
 
 void gt_querymatch_init(GtQuerymatch *querymatch,
                         GtUword dblen,
                         GtUword dbstart,
                         GtUword dbseqnum,
                         GtUword dbstart_relative,
-                        GtReadmode readmode,
-                        bool query_as_reversecopy,
                         GtWord score,
-                        GtUword edist,
+                        GtUword distance,
                         bool selfmatch,
                         uint64_t queryseqnum,
                         GtUword querylen,
                         GtUword querystart,
                         GtUword query_totallength);
 
-void gt_querymatch_delete(GtQuerymatch *querymatch);
+bool gt_querymatch_read_line(GtQuerymatch *querymatchptr,
+                             const char *line_ptr,
+                             bool selfmatch,
+                             GtUword seedpos1,
+                             GtUword seedpos2,
+                             GtUword seedlen,
+                             const GtEncseq *dbencseq,
+                             const GtEncseq *queryencseq);
 
-int gt_querymatch_output(GT_UNUSED void *info,
-                         GT_UNUSED const GtEncseq *encseq,
-                         const GtQuerymatch *querymatch,
-                         GT_UNUSED const GtUchar *query,
-                         GT_UNUSED GtUword query_totallength,
-                         GT_UNUSED GtError *err);
+bool gt_querymatch_process(GtQuerymatch *querymatchptr,
+                           const GtEncseq *encseq,
+                           const GtSeqorEncseq *query,
+                           GtUword query_totallength,
+                           bool greedyextension);
+
+void gt_querymatch_delete(GtQuerymatch *querymatch);
 
 bool gt_querymatch_complete(GtQuerymatch *querymatchptr,
                             GtUword dblen,
                             GtUword dbstart,
                             GtUword dbseqnum,
                             GtUword dbstart_relative,
-                            GtReadmode readmode,
-                            bool query_as_reversecopy,
                             GtWord score,
-                            GtUword edist,
+                            GtUword distance,
                             bool selfmatch,
                             uint64_t queryseqnum,
                             GtUword querylen,
                             GtUword querystart,
                             const GtEncseq *encseq,
-                            GT_UNUSED const GtUchar *query,
+                            const GtSeqorEncseq *query,
                             GtUword query_totallength,
                             GtUword seedpos1,
                             GtUword seedpos2,
@@ -86,15 +99,51 @@ const GtUchar *gt_querymatch_querysequence(const GtQuerymatch *querymatch);
 
 GtUword gt_querymatch_querytotallength(const GtQuerymatch *querymatch);
 
-GtUword gt_querymatch_dbseqnum(const GtEncseq *encseq,
-                                     const GtQuerymatch *querymatch);
+GtUword gt_querymatch_dbseqnum(const GtQuerymatch *querymatch);
+
+GtUword gt_querymatch_dblen(const GtQuerymatch *querymatch);
 
 bool gt_querymatch_queryreverse(const GtQuerymatch *querymatch);
 
 double gt_querymatch_error_rate(GtUword distance,GtUword alignedlen);
 
+GtUword gt_querymatch_distance(const GtQuerymatch *querymatch);
+
 void gt_querymatch_prettyprint(const GtQuerymatch *querymatch);
 
+void gt_querymatch_coordinates_out(const GtQuerymatch *querymatch);
+
+bool gt_querymatch_check_final(const GtQuerymatch *querymatch,
+                               GtUword errorpercentage,
+                               GtUword userdefinedleastlength);
+
+void gt_querymatch_query_readmode_set(GtQuerymatch *querymatch,
+                                      GtReadmode query_readmode);
+
+void gt_querymatch_verify_alignment_set(GtQuerymatch *querymatch);
+
+GtReadmode gt_querymatch_query_readmode(const GtQuerymatch *querymatch);
+
+bool gt_querymatch_selfmatch(const GtQuerymatch *querymatch);
+
 GtWord gt_querymatch_distance2score(GtUword distance,GtUword alignedlen);
 
+/* Returns true, iff the given seed start position is below the querymatch. */
+bool gt_querymatch_overlap(const GtQuerymatch *querymatch,
+                           GtUword start_relative);
+
+bool gt_querymatch_has_seed(const GtQuerymatch *querymatch);
+
+GtUword gt_querymatch_querystart_fwdstrand(const GtQuerymatch *querymatch);
+
+void gt_querymatch_table_add(GtArrayGtQuerymatch *querymatch_table,
+                             const GtQuerymatch *querymatch);
+
+void gt_querymatch_table_sort(GtArrayGtQuerymatch *querymatch_table,
+                              bool ascending);
+
+GtQuerymatch *gt_querymatch_table_get(const GtArrayGtQuerymatch
+                                        *querymatch_table,GtUword idx);
+
+const GtAlignment *gt_querymatch_alignment_get(const GtQuerymatch *querymatch);
 #endif
