@@ -22,7 +22,7 @@
 struct GtTwobitencEditor
 {
   GtTwobitencoding *twobitencoding;
-  unsigned long *charcount;
+  GtUword *charcount;
   unsigned char *mapptr;
 };
 
@@ -57,7 +57,7 @@ GtTwobitencEditor *gt_twobitenc_editor_new(const GtEncseq *encseq,
   had_err = gt_twobitenc_editor_check(encseq, err);
   if (had_err == 0)
   {
-    t_offset = gt_encseq_twobitencoding_mapoffset(encseq);
+    t_offset = gt_encseq_sequence_mapoffset(encseq);
     c_offset = gt_encseq_chardistri_mapoffset(encseq);
     encseqfilename = gt_str_new_cstr(indexname);
     gt_str_append_cstr(encseqfilename, GT_ENCSEQFILESUFFIX);
@@ -65,7 +65,7 @@ GtTwobitencEditor *gt_twobitenc_editor_new(const GtEncseq *encseq,
           encseqfilename), NULL, err);
     twobitenc_editor->twobitencoding = (GtTwobitencoding*)
       (twobitenc_editor->mapptr + t_offset);
-    twobitenc_editor->charcount = (unsigned long*)
+    twobitenc_editor->charcount = (GtUword*)
       (twobitenc_editor->mapptr + c_offset);
     gt_str_delete(encseqfilename);
   }
@@ -73,7 +73,7 @@ GtTwobitencEditor *gt_twobitenc_editor_new(const GtEncseq *encseq,
 }
 
 void gt_twobitenc_editor_edit(GtTwobitencEditor *twobitenc_editor,
-    unsigned long pos, GtUchar newchar)
+    GtUword pos, GtUchar newchar)
 {
   size_t codenum, posincode;
   GtTwobitencoding oldcode, newcode;
@@ -84,7 +84,8 @@ void gt_twobitenc_editor_edit(GtTwobitencEditor *twobitenc_editor,
   oldcode = twobitenc_editor->twobitencoding[codenum];
   posincode = (GT_UNITSIN2BITENC - 1 -
       ((size_t)pos % GT_UNITSIN2BITENC)) << 1;
-  oldchar = (oldcode & ((GtTwobitencoding)3 << posincode)) >> posincode;
+  oldchar = (GtUchar) (oldcode & ((GtTwobitencoding)3 << posincode))
+               >> posincode;
   newcode = (oldcode & (~((GtTwobitencoding)3 << posincode)));
   newcode |= ((GtTwobitencoding)newchar << posincode);
   twobitenc_editor->twobitencoding[codenum] = newcode;
