@@ -1,6 +1,6 @@
 /*
-  Copyright (c) 2006-2011 Gordon Gremme <gremme@zbh.uni-hamburg.de>
-  Copyright (c) 2006-2008 Center for Bioinformatics, University of Hamburg
+  Copyright (c) 2006-2011, 2013 Gordon Gremme <gordon@gremme.org>
+  Copyright (c) 2006-2008       Center for Bioinformatics, University of Hamburg
 
   Permission to use, copy, modify, and distribute this software for any
   purpose with or without fee is hereby granted, provided that the above
@@ -15,6 +15,7 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
+#include "core/ma_api.h"
 #include "core/option_api.h"
 #include "core/output_file_api.h"
 #include "core/versionfunc.h"
@@ -24,40 +25,69 @@
 #include "extended/merge_stream_api.h"
 #include "tools/gt_merge.h"
 
-static GtOPrval parse_options(int *parsed_args, GtFile **outfp, int argc,
-                              const char **argv, GtError *err)
-{
-  GtOptionParser *op;
+typedef struct {
   GtOutputFileInfo *ofi;
-  GtOPrval oprval;
-  gt_error_check(err);
-  op = gt_option_parser_new("[option ...] [GFF3_file ...]",
-                         "Merge sorted GFF3 files in sorted fashion.");
-  ofi = gt_output_file_info_new();
-  gt_output_file_register_options(op, outfp, ofi);
-  oprval = gt_option_parser_parse(op, parsed_args, argc, argv, gt_versionfunc,
-                                  err);
-  gt_output_file_info_delete(ofi);
-  gt_option_parser_delete(op);
-  return oprval;
+  GtFile *outfp;
+  bool retainids,
+       tidy;
+} MergeArguments;
+
+static void* gt_merge_arguments_new(void)
+{
+  MergeArguments *arguments = gt_calloc(1, sizeof *arguments);
+  arguments->ofi = gt_output_file_info_new();
+  return arguments;
 }
 
-int gt_merge(int argc, const char **argv, GtError *err)
+static void gt_merge_arguments_delete(void *tool_arguments)
 {
+  MergeArguments *arguments = tool_arguments;
+  if (!arguments) return;
+  gt_file_delete(arguments->outfp);
+  gt_output_file_info_delete(arguments->ofi);
+  gt_free(arguments);
+}
+
+static GtOptionParser* gt_merge_option_parser_new(void *tool_arguments)
+{
+  MergeArguments *arguments = tool_arguments;
+  GtOptionParser *op;
+  GtOption *option;
+  gt_assert(arguments);
+  op = gt_option_parser_new("[option ...] [GFF3_file ...]",
+                         "Merge sorted GFF3 files in sorted fashion.");
+
+  /* -retainids */
+  option = gt_option_new_bool("retainids",
+                              "when available, use the original IDs provided "
+                              "in the source file\n"
+                              "(memory consumption is proportional to the "
+                              "input file size(s))", &arguments->retainids,
+                              false);
+  gt_option_parser_add_option(op, option);
+
+  /* -tidy */
+  option = gt_option_new_bool("tidy", "try to tidy the GFF3 files up "
+                              "during parsing", &arguments->tidy, false);
+  gt_option_parser_add_option(op, option);
+
+  gt_output_file_info_register_options(arguments->ofi, op, &arguments->outfp);
+  return op;
+}
+
+static int gt_merge_runner(int argc, const char **argv, int parsed_args,
+                           void *tool_arguments, GtError *err)
+{
+  MergeArguments *arguments = tool_arguments;
   GtNodeStream *gff3_in_stream,
                 *merge_stream,
                 *gff3_out_stream;
   GtArray *genome_streams;
-  unsigned long i;
-  int parsed_args, had_err;
-  GtFile *outfp;
+  GtUword i;
+  int had_err;
 
-  /* option parsing */
-  switch (parse_options(&parsed_args, &outfp, argc, argv, err)) {
-    case GT_OPTION_PARSER_OK: break;
-    case GT_OPTION_PARSER_ERROR: return -1;
-    case GT_OPTION_PARSER_REQUESTS_EXIT: return 0;
-  }
+  gt_error_check(err);
+  gt_assert(arguments);
 
   /* alloc */
   genome_streams = gt_array_new(sizeof (GtNodeStream*));
@@ -69,6 +99,8 @@ int gt_merge(int argc, const char **argv, GtError *err)
     /* we got files to open */
     for (i = parsed_args; i < argc; i++) {
       gff3_in_stream = gt_gff3_in_stream_new_sorted(argv[i]);
+      if (arguments->tidy)
+        gt_gff3_in_stream_enable_tidy_mode((GtGFF3InStream*) gff3_in_stream);
       gt_array_add(genome_streams, gff3_in_stream);
     }
    }
@@ -80,9 +112,12 @@ int gt_merge(int argc, const char **argv, GtError *err)
 
   /* create a merge stream */
   merge_stream = gt_merge_stream_new(genome_streams);
+  gt_assert(merge_stream);
 
   /* create a gff3 output stream */
-  gff3_out_stream = gt_gff3_out_stream_new(merge_stream, outfp);
+  gff3_out_stream = gt_gff3_out_stream_new(merge_stream, arguments->outfp);
+  if (arguments->retainids)
+    gt_gff3_out_stream_retain_id_attributes((GtGFF3OutStream*) gff3_out_stream);
 
   /* pull the features through the stream and free them afterwards */
   had_err = gt_node_stream_pull(gff3_out_stream, err);
@@ -93,7 +128,15 @@ int gt_merge(int argc, const char **argv, GtError *err)
   for (i = 0; i < gt_array_size(genome_streams); i++)
     gt_node_stream_delete(*(GtNodeStream**) gt_array_get(genome_streams, i));
   gt_array_delete(genome_streams);
-  gt_file_delete(outfp);
 
   return had_err;
 }
+
+GtTool* gt_merge(void)
+{
+  return gt_tool_new(gt_merge_arguments_new,
+                     gt_merge_arguments_delete,
+                     gt_merge_option_parser_new,
+                     NULL,
+                     gt_merge_runner);
+}
