@@ -37,8 +37,8 @@
 struct chkSearchOptions
 {
   struct bwtOptions idx;
-  long minPatLen, maxPatLen;
-  unsigned long numOfSamples, progressInterval;
+  GtWord minPatLen, maxPatLen;
+  GtUword numOfSamples, progressInterval;
   int flags;
   bool verboseOutput;
 };
@@ -115,8 +115,8 @@ gt_packedindex_chk_search(int argc, const char *argv[], GtError *err)
       EMIterInitialized = true;
     }
     {
-      unsigned long totalLen, dbstart;
-      unsigned long trial, patternLen;
+      GtUword totalLen, dbstart;
+      GtUword trial, patternLen;
 
       if ((had_err =
            gt_mapsuffixarray(&suffixarray, SARR_SUFTAB | SARR_ESQTAB,
@@ -131,9 +131,10 @@ gt_packedindex_chk_search(int argc, const char *argv[], GtError *err)
       if ((had_err = (params.minPatLen >= 0L && params.maxPatLen >= 0L
                       && params.minPatLen > params.maxPatLen)))
       {
-        gt_error_set(err, "Invalid pattern lengths selected: min=%ld, max=%ld;"
-                  " min <= max is required.", params.minPatLen,
-                  params.maxPatLen);
+        gt_error_set(err, "Invalid pattern lengths selected: min="GT_WD", "
+                     "max="GT_WD";"
+                     " min <= max is required.", params.minPatLen,
+                     params.maxPatLen);
         break;
       }
       if (params.minPatLen < 0 || params.maxPatLen < 0)
@@ -156,12 +157,12 @@ gt_packedindex_chk_search(int argc, const char *argv[], GtError *err)
         else
           params.maxPatLen = MAX(params.maxPatLen, params.minPatLen);
       }
-      fprintf(stderr, "Using patterns of lengths %lu to %lu\n",
+      fprintf(stderr, "Using patterns of lengths "GT_WU" to "GT_WU"\n",
               params.minPatLen, params.maxPatLen);
       if ((had_err = totalLen + 1 != BWTSeqLength(bwtSeq)))
       {
         gt_error_set(err, "base suffix array and index have diferrent lengths!"
-                          "%lu vs. %lu",  totalLen + 1,
+                          ""GT_WU" vs. "GT_WU"",  totalLen + 1,
                   BWTSeqLength(bwtSeq));
         break;
       }
@@ -177,7 +178,7 @@ gt_packedindex_chk_search(int argc, const char *argv[], GtError *err)
       {
         const GtUchar *pptr = gt_nextEnumpatterniterator(&patternLen, epi);
         GtMMsearchiterator *mmsi =
-          gt_mmsearchiterator_new_complete_olain(suffixarray.encseq,
+          gt_mmsearchiterator_new_complete_plain(suffixarray.encseq,
                                             suffixarray.suftab,
                                             0,  /* leftbound */
                                             totalLen, /* rightbound */
@@ -201,7 +202,7 @@ gt_packedindex_chk_search(int argc, const char *argv[], GtError *err)
                       == gt_mmsearchiterator_count(mmsi));
           while (gt_mmsearchiterator_next(&dbstart,mmsi))
           {
-            unsigned long matchPos = 0;
+            GtUword matchPos = 0;
             bool match = EMIGetNextMatch(&EMIter, &matchPos, bwtSeq);
             if ((had_err = !match))
             {
@@ -212,13 +213,13 @@ gt_packedindex_chk_search(int argc, const char *argv[], GtError *err)
             if ((had_err = matchPos != dbstart))
             {
               gt_error_set(err, "packedindex match doesn't equal mmsearch "
-                           "match result!\n%lu vs. %lu\n",
+                           "match result!\n"GT_WU" vs. "GT_WU"\n",
                            matchPos, dbstart);
             }
           }
           if (!had_err)
           {
-            unsigned long matchPos;
+            GtUword matchPos;
             bool trailingMatch = EMIGetNextMatch(&EMIter, &matchPos, bwtSeq);
             if ((had_err = trailingMatch))
             {
@@ -229,14 +230,14 @@ gt_packedindex_chk_search(int argc, const char *argv[], GtError *err)
         }
         else
         {
-          unsigned long numFMIMatches = gt_BWTSeqMatchCount(bwtSeq, pptr,
+          GtUword numFMIMatches = gt_BWTSeqMatchCount(bwtSeq, pptr,
                                                          patternLen,
                                                          false),
             numMMSearchMatches = gt_mmsearchiterator_count(mmsi);
           if ((had_err = numFMIMatches != numMMSearchMatches))
           {
             gt_error_set(err, "Number of matches not equal for suffix array ("
-                              "%lu) and fmindex (%lu).\n",
+                              ""GT_WU") and fmindex ("GT_WU").\n",
                       numFMIMatches, numMMSearchMatches);
           }
         }
@@ -247,7 +248,7 @@ gt_packedindex_chk_search(int argc, const char *argv[], GtError *err)
       }
       if (params.progressInterval)
         putc('\n', stderr);
-      fprintf(stderr, "Finished %lu of %lu matchings successfully.\n",
+      fprintf(stderr, "Finished "GT_WU" of "GT_WU" matchings successfully.\n",
               trial, params.numOfSamples);
     }
   } while (0);
@@ -279,19 +280,19 @@ parseChkBWTOptions(int *parsed_args, int argc, const char **argv,
   gt_registerPackedIndexOptions(op, &params->idx, BWTDEFOPT_MULTI_QUERY,
                              projectName);
 
-  option = gt_option_new_long("minpatlen",
+  option = gt_option_new_word("minpatlen",
                            "minimum length of patterns searched for, -1 "
                            "implies automatic choice based on index "
                            "properties", &params->minPatLen, -1);
   gt_option_parser_add_option(op, option);
 
-  option = gt_option_new_long("maxpatlen",
+  option = gt_option_new_word("maxpatlen",
                            "maximum length of patterns searched for, -1 "
                            "implies automatic choice based on index "
                            "properties", &params->maxPatLen, -1);
   gt_option_parser_add_option(op, option);
 
-  option = gt_option_new_ulong("nsamples",
+  option = gt_option_new_uword("nsamples",
                             "number of sequences to search for",
                             &params->numOfSamples, 1000);
   gt_option_parser_add_option(op, option);
@@ -311,7 +312,7 @@ parseChkBWTOptions(int *parsed_args, int argc, const char **argv,
                            &tryContextRetrieve, false);
   gt_option_parser_add_option(op, option);
 
-  optionProgress = gt_option_new_ulong("ticks",
+  optionProgress = gt_option_new_uword("ticks",
                                     "print dot after this many symbols "
                                     "tested okay", &params->progressInterval,
                                     DEFAULT_PROGRESS_INTERVAL);
