@@ -36,7 +36,8 @@ typedef struct {
   unsigned int minmatchlength;
   unsigned int lengthcutoff, depthcutoff;
   GtStr  *readset, *buffersizearg;
-  bool errors, paths2seq, redtrans, save, load, vd, astat, copynum;
+  bool errors, paths2seq, redtrans, save, load, vd, astat, copynum,
+       show_contigs_info;
   unsigned int deadend, bubble, deadend_depth;
   GtOption *refoptionbuffersize;
   GtUword buffersize;
@@ -211,6 +212,13 @@ static GtOptionParser* gt_readjoiner_assembly_option_parser_new(
   gt_option_is_development_option(option);
   gt_option_parser_add_option(op, option);
 
+  /* -show_contigs_info */
+  option = gt_option_new_bool("cinfo", "output additional files required "
+      "for contigs graph construction (eqlen only)",
+      &arguments->show_contigs_info, false);
+  gt_option_is_development_option(option);
+  gt_option_parser_add_option(op, option);
+
   gt_option_parser_set_version_func(op, gt_readjoiner_show_version);
   gt_option_parser_set_max_args(op, 0);
 
@@ -479,7 +487,7 @@ static int gt_readjoiner_assembly_runner(GT_UNUSED int argc,
   GtStrgraph *strgraph = NULL;
   GtBitsequence *contained = NULL;
   const char *readset = gt_str_get(arguments->readset);
-  bool eqlen;
+  bool eqlen = true;
   GtUword nreads, tlen, rlen;
   int had_err = 0;
 
@@ -507,29 +515,35 @@ static int gt_readjoiner_assembly_runner(GT_UNUSED int argc,
     gt_encseq_loader_drop_description_support(el);
     gt_encseq_loader_disable_autosupport(el);
     reads = gt_encseq_loader_load(el, readset, err);
-    gt_assert(reads != NULL);
-    eqlen = gt_encseq_accesstype_get(reads) == GT_ACCESS_TYPE_EQUALLENGTH;
-    nreads = gt_encseq_num_of_sequences(reads);
-    gt_logger_log(default_logger, "number of reads in filtered readset = "
-                  GT_WU, nreads);
-    tlen = gt_encseq_total_length(reads) - nreads + 1;
-    gt_logger_log(verbose_logger, "total length of filtered readset = " GT_WU,
-        tlen);
-
-    if (eqlen)
+    if (reads == NULL)
     {
-      rlen = gt_encseq_seqlength(reads, 0);
-      gt_logger_log(verbose_logger, "read length = " GT_WU, rlen);
-      gt_encseq_delete(reads);
-      reads = NULL;
+      had_err = -1;
     }
-    else
+    if (had_err == 0)
     {
-      had_err = gt_readjoiner_assembly_build_contained_reads_list(
-        arguments, &contained, err);
-      rlen = 0;
-      gt_logger_log(verbose_logger, "read length = variable");
-      gt_assert(reads != NULL);
+      eqlen = gt_encseq_accesstype_get(reads) == GT_ACCESS_TYPE_EQUALLENGTH;
+      nreads = gt_encseq_num_of_sequences(reads);
+      gt_logger_log(default_logger, "number of reads in filtered readset = "
+                    GT_WU, nreads);
+      tlen = gt_encseq_total_length(reads) - nreads + 1;
+      gt_logger_log(verbose_logger, "total length of filtered readset = " GT_WU,
+          tlen);
+
+      if (eqlen)
+      {
+        rlen = gt_encseq_seqlength(reads, 0);
+        gt_logger_log(verbose_logger, "read length = " GT_WU, rlen);
+        gt_encseq_delete(reads);
+        reads = NULL;
+      }
+      else
+      {
+        had_err = gt_readjoiner_assembly_build_contained_reads_list(
+          arguments, &contained, err);
+        rlen = 0;
+        gt_logger_log(verbose_logger, "read length = variable");
+        gt_assert(reads != NULL);
+      }
     }
 
     if (had_err == 0)
@@ -605,8 +619,8 @@ static int gt_readjoiner_assembly_runner(GT_UNUSED int argc,
       gt_readjoiner_assembly_show_current_space("(before traversal)");
       gt_strgraph_spell(strgraph, (GtUword)arguments->depthcutoff,
           (GtUword)arguments->lengthcutoff, arguments->vd, readset,
-          GT_READJOINER_SUFFIX_CONTIG_PATHS, NULL, true, false,
-          verbose_logger);
+          GT_READJOINER_SUFFIX_CONTIG_PATHS, NULL, true,
+          arguments->show_contigs_info, false, verbose_logger);
     }
 
     if (contained != NULL)
