@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2010 Gordon Gremme <gremme@zbh.uni-hamburg.de>
+  Copyright (c) 2010 Gordon Gremme <gordon@gremme.org>
 
   Permission to use, copy, modify, and distribute this software for any
   purpose with or without fee is hereby granted, provided that the above
@@ -24,7 +24,7 @@
 
 typedef struct {
   bool addstopaminos;
-  unsigned long width;
+  GtUword width;
   GtOutputFileInfo *ofi;
   GtFile *outfp;
 } SeqtransformArguments;
@@ -66,7 +66,7 @@ static GtOptionParser* gt_seqtransform_option_parser_new(void *tool_arguments)
   o = gt_option_new_width(&arguments->width);
   gt_option_parser_add_option(op, o);
 
-  gt_output_file_register_options(op, &arguments->outfp, arguments->ofi);
+  gt_output_file_info_register_options(arguments->ofi, op, &arguments->outfp);
 
   return op;
 }
@@ -76,7 +76,7 @@ static int gt_seqtransform_runner(int argc, const char **argv, int parsed_args,
 {
   SeqtransformArguments *arguments = tool_arguments;
   GtBioseqIterator *bsi;
-  unsigned long i;
+  GtUword i;
   GtBioseq *bioseq;
   int had_err;
 
@@ -93,7 +93,7 @@ static int gt_seqtransform_runner(int argc, const char **argv, int parsed_args,
     for (i = 0; i < gt_bioseq_number_of_sequences(bioseq); i++) {
       const char *desc, *suffix = NULL;
       char *seq;
-      unsigned long seqlen;
+      GtUword seqlen;
       desc = gt_bioseq_get_description(bioseq, i);
       seq = gt_bioseq_get_sequence(bioseq, i);
       seqlen = gt_bioseq_get_sequence_length(bioseq, i);
