@@ -24,10 +24,11 @@
 #include "core/ma_api.h"
 #include "core/option_api.h"
 #include "core/str.h"
+#include "core/tool.h"
+#include "core/toolbox.h"
 #include "core/unused_api.h"
 #include "core/versionfunc.h"
 #include "core/minmax.h"
-#include "extended/toolbox.h"
 #include "match/optionargmode.h"
 #include "match/tyr-mkindex.h"
 #include "match/tyr-show.h"
@@ -51,7 +52,7 @@ typedef struct
 
 typedef struct
 {
-  unsigned long mersize,
+  GtUword mersize,
                 userdefinedminocc,
                 userdefinedmaxocc;
   unsigned int userdefinedprefixlength;
@@ -113,14 +114,14 @@ static GtOptionParser *gt_tyr_mkindex_option_parser_new(void *tool_arguments)
   gt_option_is_mandatory(optionesa);
   gt_option_parser_add_option(op, optionesa);
 
-  option = gt_option_new_ulong("mersize",
+  option = gt_option_new_uword("mersize",
                                "Specify the mer size.",
                                &arguments->mersize,
                                20UL);
   gt_option_parser_add_option(op, option);
 
   optionminocc
-    = gt_option_new_ulong("minocc",
+    = gt_option_new_uword("minocc",
                           "Specify the minimum occurrence number for "
                           "the mers to output/index",
                           &arguments->userdefinedminocc,
@@ -128,7 +129,7 @@ static GtOptionParser *gt_tyr_mkindex_option_parser_new(void *tool_arguments)
   gt_option_parser_add_option(op, optionminocc);
 
   optionmaxocc
-    = gt_option_new_ulong("maxocc",
+    = gt_option_new_uword("maxocc",
                           "Specify the maximum occurrence number for "
                           "the mers to output/index",
                           &arguments->userdefinedmaxocc,
@@ -221,17 +222,17 @@ static int gt_tyr_mkindex_runner(GT_UNUSED int argc,
   logger = gt_logger_new(arguments->verbose, GT_LOGGER_DEFLT_PREFIX, stdout);
   if (arguments->verbose)
   {
-    printf("# mersize=%lu\n",arguments->mersize);
+    printf("# mersize="GT_WU"\n",arguments->mersize);
     if (arguments->userdefinedminocc > 0)
     {
-      printf("# minocc=%lu\n",arguments->userdefinedminocc);
+      printf("# minocc="GT_WU"\n",arguments->userdefinedminocc);
     } else
     {
       printf("# minocc=undefined\n");
     }
     if (arguments->userdefinedmaxocc > 0)
     {
-      printf("# maxocc=%lu\n",arguments->userdefinedmaxocc);
+      printf("# maxocc="GT_WU"\n",arguments->userdefinedmaxocc);
     } else
     {
       printf("# maxocc=undefined\n");
@@ -308,7 +309,7 @@ typedef struct
   GtStrArray *mersizesstrings, *outputspec;
   GtStr *str_inputindex;
   GtOption *refoptionmersizes;
-  unsigned long minmersize, maxmersize, stepmersize;
+  GtUword minmersize, maxmersize, stepmersize;
   GtBitsequence *outputvector;
   unsigned int outputmode;
   bool scanfile,
@@ -363,21 +364,21 @@ static GtOptionParser *gt_tyr_occratio_option_parser_new(void *tool_arguments)
   gt_option_parser_add_option(op, optionesa);
 
   optionminmersize
-    = gt_option_new_ulong_min("minmersize",
+    = gt_option_new_uword_min("minmersize",
                               "specify minimum mer size for which "
                               "to compute the occurrence distribution",
                               &arguments->minmersize,0,1UL);
   gt_option_parser_add_option(op, optionminmersize);
 
   optionmaxmersize
-    = gt_option_new_ulong_min("maxmersize",
+    = gt_option_new_uword_min("maxmersize",
                               "specify maximum mer size for which "
                               "to compute the occurrence distribution",
                               &arguments->maxmersize,0,1UL);
   gt_option_parser_add_option(op, optionmaxmersize);
 
   optionstep
-    = gt_option_new_ulong_min("step",
+    = gt_option_new_uword_min("step",
                               "specify step size when specifying mer sizes",
                               &arguments->stepmersize,1UL,1UL);
   gt_option_parser_add_option(op, optionstep);
@@ -445,8 +446,8 @@ static int gt_tyr_occratio_arguments_check(int rest_argc,
   }
   if (gt_option_is_set(arguments->refoptionmersizes))
   {
-    unsigned long *mersizes = NULL;
-    unsigned long idx,
+    GtUword *mersizes = NULL;
+    GtUword idx,
                   numofmersizes = gt_str_array_size(arguments->mersizesstrings);
     if (numofmersizes == 0)
     {
@@ -457,10 +458,10 @@ static int gt_tyr_occratio_arguments_check(int rest_argc,
       mersizes = gt_malloc(sizeof (*mersizes) * numofmersizes);
       for (idx=0; idx<numofmersizes; idx++)
       {
-        long readnum;
+        GtWord readnum;
 
         if (sscanf(gt_str_array_get(arguments->mersizesstrings,idx),
-                   "%ld",&readnum) != 1 || readnum <= 0)
+                   ""GT_WD"",&readnum) != 1 || readnum <= 0)
         {
           gt_error_set(err,"invalid argument \"%s\" of option -mersizes: "
                        "must be a positive integer",
@@ -468,7 +469,7 @@ static int gt_tyr_occratio_arguments_check(int rest_argc,
           haserr = true;
           break;
         }
-        mersizes[idx] = (unsigned long) readnum;
+        mersizes[idx] = (GtUword) readnum;
         if (idx > 0 && mersizes[idx-1] >= mersizes[idx])
         {
           gt_error_set(err,"invalid argumnt %s to option -mersizes: "
@@ -528,7 +529,7 @@ static int gt_tyr_occratio_arguments_check(int rest_argc,
     }
     if (!haserr)
     {
-      unsigned long outputval;
+      GtUword outputval;
 
       GT_INITBITTAB(arguments->outputvector,arguments->maxmersize+1);
       for (outputval = arguments->minmersize;
@@ -541,7 +542,7 @@ static int gt_tyr_occratio_arguments_check(int rest_argc,
   }
   if (!haserr)
   {
-    unsigned long idx;
+    GtUword idx;
     for (idx=0; idx<gt_str_array_size(arguments->outputspec); idx++)
     {
       if (gt_optionargaddbitmask(outputmodedesctable,
@@ -576,7 +577,7 @@ static int gt_tyr_occratio_arguments_check(int rest_argc,
 static void showitvdistribution(const GtArrayuint64_t *dist,
                                 const GtBitsequence *outputvector)
 {
-  unsigned long idx;
+  GtUword idx;
 
   gt_assert(outputvector != NULL);
   for (idx=0; idx < dist->nextfreeuint64_t; idx++)
@@ -584,7 +585,7 @@ static void showitvdistribution(const GtArrayuint64_t *dist,
     if (GT_ISIBITSET(outputvector,idx) && dist->spaceuint64_t[idx] > 0)
     {
       /*@ignore@*/
-      printf("%lu " Formatuint64_t "\n",
+      printf(""GT_WU" " Formatuint64_t "\n",
               idx,
               PRINTuint64_tcast(dist->spaceuint64_t[idx]));
       /*@end@*/
@@ -604,7 +605,7 @@ static void showitvsumdistributionoftwo(Summode mode,
                                         const GtArrayuint64_t *dist2,
                                         const GtBitsequence *outputvector)
 {
-  unsigned long idx;
+  GtUword idx;
   uint64_t sumoftwo, tmp;
 
   gt_assert(outputvector != NULL);
@@ -636,7 +637,7 @@ static void showitvsumdistributionoftwo(Summode mode,
         if (mode == Onlyshowsum)
         {
           /*@ignore@*/
-          printf("%lu " Formatuint64_t "\n",
+          printf(""GT_WU" " Formatuint64_t "\n",
                   idx,
                   PRINTuint64_tcast(sumoftwo));
           /*@end@*/
@@ -656,7 +657,7 @@ static void showitvsumdistributionoftwo(Summode mode,
           if (tmp > 0)
           {
             /*@ignore@*/
-            printf("%lu " Formatuint64_t " %.3f\n",
+            printf(""GT_WU" " Formatuint64_t " %.3f\n",
                   idx,
                   PRINTuint64_tcast(tmp),
                   (double) tmp/(double) sumoftwo);
@@ -836,7 +837,7 @@ static GtOptionParser *gt_tyr_search_option_parser_new(void *tool_arguments)
   op = gt_option_parser_new("[options] -tyr tallymer-index -q queryfile0 "
                             "[queryfile1..] [options]",
                             "Search a set of k-mers in an index constructed "
-                            "by \"gt tyr mkindex\".");
+                            "by ``gt tallymer mkindex''.");
   gt_option_parser_set_mail_address(op, "<kurtz@zbh.uni-hamburg.de>");
 
   optiontyr = gt_option_new_string("tyr","specify tallymer-index",
@@ -895,7 +896,7 @@ static int gt_tyr_search_arguments_check(int rest_argc,
     {"p","reverse strand",STRAND_REVERSE},
     {"fp","forward and reverse strand",STRAND_FORWARD | STRAND_REVERSE}
   };
-  unsigned long idx;
+  GtUword idx;
   Tyr_search_options *arguments = tool_arguments;
 
   if (rest_argc != 0)
@@ -982,8 +983,7 @@ static GtOptionParser* gt_tyr_option_parser_new(void *tool_arguments)
   gt_assert(index_toolbox != NULL);
   op = gt_option_parser_new(
                     "[option ...] tallymer_tool [argument ...]",
-                    "Call tallymer tool with name tallymer_tool and pass "
-                    "argument(s) to it.");
+                    "Call a tallymer subtool and pass argument(s) to it.");
   gt_option_parser_set_comment_func(op, gt_toolbox_show, index_toolbox);
   gt_option_parser_set_min_args(op, 1U);
   gt_option_parser_refer_to_manual(op);
@@ -1032,9 +1032,11 @@ static int gt_tyr_runner(int argc, const char **argv, int parsed_args,
 
 GtTool* gt_tallymer(void)
 {
-  return gt_tool_new(gt_tyr_arguments_new,
-                     gt_tyr_arguments_delete,
-                     gt_tyr_option_parser_new,
-                     NULL,
-                     gt_tyr_runner);
+  GtTool *tool = gt_tool_new(gt_tyr_arguments_new,
+                             gt_tyr_arguments_delete,
+                             gt_tyr_option_parser_new,
+                             NULL,
+                             gt_tyr_runner);
+  gt_tool_set_toolbox_new(tool, (GtToolToolboxNew) gt_tyr_arguments_new);
+  return tool;
 }
