@@ -26,7 +26,7 @@ typedef struct {
 
 static void* gt_template_arguments_new(void)
 {
-  TemplateArguments *arguments = gt_calloc(1, sizeof *arguments);
+  TemplateArguments *arguments = gt_calloc((size_t) 1, sizeof *arguments);
   arguments->str_option_template = gt_str_new();
   return arguments;
 }
@@ -34,9 +34,10 @@ static void* gt_template_arguments_new(void)
 static void gt_template_arguments_delete(void *tool_arguments)
 {
   TemplateArguments *arguments = tool_arguments;
-  if (!arguments) return;
-  gt_str_delete(arguments->str_option_template);
-  gt_free(arguments);
+  if (arguments != NULL) {
+    gt_str_delete(arguments->str_option_template);
+    gt_free(arguments);
+  }
 }
 
 static GtOptionParser* gt_template_option_parser_new(void *tool_arguments)
