@@ -1,7 +1,7 @@
 name        = "Name here"
 author      = "Sascha Kastens"
 version     = "1.0"
-email       = "sascha.kastens@studium.uni-hamburg.de"
+email       = "mail@skastens.de"
 short_descr = "Short description here."
 description = "Description here"
 
