@@ -12,6 +12,13 @@ Test do
   grep last_stderr, "unknown option"
 end
 
+Name "gt gff3 revision numbers"
+Keywords "gt_gff3"
+Test do
+  run_test "#{$bin}gt gff3 #{$testdata}revision_numbers.gff3"
+  run "diff #{last_stdout} #{$testdata}revision_numbers.out"
+end
+
 Name "gt gff3 short test (stdin)"
 Keywords "gt_gff3"
 Test do
@@ -1448,18 +1455,6 @@ Test do
   run "diff 1 3"
 end
 
-Name "gt gff3 -sortlines (three partially overlapping genes)"
-Keywords "gt_gff3 linesorting"
-Test do
-  run "#{$bin}gt #{$testdata}/gtscripts/check_linesorting.lua #{$testdata}gt_gff3_linesort2.in.gff3", :retval => 1
-  run_test "#{$bin}gt gff3 -sort -retainids #{$testdata}gt_gff3_linesort2.in.gff3 > 1"
-  run "#{$bin}gt #{$testdata}/gtscripts/check_linesorting.lua 1", :retval => 1
-  run_test "#{$bin}gt gff3 -sort -retainids -sortlines #{$testdata}gt_gff3_linesort2.in.gff3 > 2"
-  run "#{$bin}gt #{$testdata}/gtscripts/check_linesorting.lua 2"
-  run_test "#{$bin}gt gff3 -sort -retainids 2 > 3"
-  run "diff 1 3"
-end
-
 Name "gt gff3 -sortlines (multiple sequences)"
 Keywords "gt_gff3 linesorting"
 Test do
@@ -1490,6 +1485,15 @@ Test do
   run "diff 1 3"
 end
 
+Name "gt gff3 -sortlines (spaces)"
+Keywords "gt_gff3 linesorting"
+Test do
+  1.upto(3) do |i|
+    run_test "#{$bin}gt gff3 -sortlines #{$testdata}linesort_test_#{i}.gff3"
+    run "diff #{last_stdout} #{$testdata}linesort_test_#{i}.out"
+  end
+end
+
 Name "gt gff3 -sortnum (standard gene)"
 Keywords "gt_gff3 numsorting"
 Test do
@@ -1553,8 +1557,15 @@ end
 if $gttestdata then
   large_gff3_test("maker", "maker/maker.gff3")
   large_gff3_test("Saccharomyces cerevisiae", "sgd/saccharomyces_cerevisiae.gff")
-  large_gff3_test("Drosophila melanogaster",
-                  "Drosophila_melanogaster.BDGP5.4.50.gff3")
+
+  Name "gt gff3 Drosophila melanogaster BDGP"
+  Keywords "gt_gff3"
+  Test do
+    run_test "#{$bin}gt gff3 -tidy -sort " +
+             "#{$gttestdata}gff3/Drosophila_melanogaster.BDGP5.4.50.gff3",
+             :maxtime => 3600
+    run      "diff #{last_stdout} #{$gttestdata}gff3/Drosophila_melanogaster.BDGP5.4.50.gff3"
+  end
 
   Name "gt gff3 TAIR10"
   Keywords "gt_gff3"
