@@ -1,5 +1,6 @@
 methods = ["radixinplace","radixlsb",
-           "thomas","system","inlinedptr","inlinedarr","direct","dual-pivot"]
+           "thomas","system","inlinedptr","inlinedarr","direct","dual-pivot",
+           "radixkeypair"]
 
 lenlist=[10,20,30,1000,2000,4000,1000000,2000000]
 
